#The following code prints the values in %/K of trends in all variables that we present in the main text as SST increases. As mentioned in the main text, the units of % are
#with respect to a reference value of each variable at an SST of 299.5K, or the mean value at this SST for the results from the "realistic" periods. The code also prints 
#the p-values for each trend. As described in the supplemental material, these p-values are calculated, for the "single-eyewall" periods and for other cases where each SST 
#corresponds to a single value of the variable, based on a two-sided Wald test with a t-distribution of the test statistic. For the results derived from the realistic 
#periods, we used a two-sided t-test, correcting for heteroskedasticity in our data with the HC1 estimator (MacKinnon and White, 1985, J. Econometrics).
#This code also saves inputs to Paper_plots.py, which makes the figures in the main text.

#Load modules
import numpy as np
from pylab import *
import netCDF4 as n4
import matplotlib.pyplot as plt
import matplotlib.dates as mdates
from matplotlib import gridspec
from math import *
import xarray as xr
from scipy import signal
from scipy import spatial
from PIL import Image
import os
import numpy.polynomial.polynomial as poly
from sklearn.metrics import r2_score
import numba
from statsmodels.regression.linear_model import OLS
import statsmodels.api as sm



#Save a quantity, end_win, for each SST, that will be used later in the code to correctly load and format data calculated during the realistic periods.
#end_win is equal to the total number of realistic periods for a given SST experiment.
#end_win is equal to the total number of realistic periods for a given SST experiment.
SSTs=np.arange(295, 308, 0.5).tolist() #SSTs range from 295K to 307.5K in steps of 0.5K for our simulations.
for i in np.arange(len(SSTs)): #Loop through all SST values
    SST_c=SSTs[i] #Set the current SST value
    if SST_c-floor(SST_c)==0: #We need any SST that is an integer value to be loaded as such, rather than a floating-point value.
                              #e.g., we want SST_c=295 and not SST_c=295.0. However, the SST as loaded will be a floating-point
                              #number. The code below converts it to an integer.
        SST_c=int(SST_c) 
    #print("SST is "+np.str(SST_c))
    windows_inds=np.load('Time_bounds_'+str(SST_c)+'_RMW_Rp.npz')['windows_inds'] #Timestep bounds for each realistic period for the simulation corresponding to the current
                                                                                 #SST value
    end_win=len(np.squeeze(windows_inds[0, :])) #Number of realistic periods for this SST simulation
    np.savez("end_win_"+str(SST_c)+"_axisymm.npz", end_win=end_win) #Save the value of end_win for later use by this code


#Load, for all SSTs and for both the single-eyewall and realistic periods, MAFALDA-derived energetic quantities calculated using all MAFALDA trajectories from the isentropic 
#streamfunction. 
Wmax_vec=[] #Wmax for the realistic periods. Mean value at each SST.
Wmax_vec_c=[] #Wmax for the realistic periods
Wmax_vec_bb_Rp=[] #Wmax for the single-eyewall periods
W_vec=[] #W for the realistic periods. Mean value at each SST.
W_vec_c=[] #W for the realistic periods
W_vec_bb_Rp=[] #W for the single-eyewall periods
Wp_vec=[] #Wp for the realistic periods. Mean value at each SST.
Wp_vec_c=[] #Wp for the realistic periods
Wp_vec_bb_Rp=[] #Wp for the single-eyewall periods
Wp_vec_bb_Rp_2=[] #Wp (W/m2) for the single-eyewall periods
Wp_vec_2=[] #Wp (W/m2) for the realistic periods. Mean value at each SST
Wp_vec_c_2=[] #Wp (W/m2) for the realistic periods
WKE_vec=[] #WKE for the realistic periods. Mean value at each SST.
WKE_vec_c=[] #WKE for the realistic periods
WKE_vec_bb_Rp=[] #WKE for the single-eyewall periods
WKE_vec_bb_Rp_2=[] #WKE (W/m2) for the single-eyewall periods
WKE_vec_2=[] #WKE (W/m2) for the realistic periods. Mean value at each SST
WKE_vec_c_2=[] #WKE (W/m2) for the realistic periods
dg_vec=[] #Gibbs penalty for the realistic periods. Mean value at each SST.
dg_vec_c=[] #Gibbs penalty for the realistic periods
dg_vec_bb_Rp=[] #Gibbs penalty for the single-eyewall periods
dg_vec_bb_Rp_2=[] #Gibbs penalty (W/m2) for the single-eyewall periods
dg_vec_2=[] #Gibbs penalty (W/m2) for the realistic periods. Mean value at each SST.
dg_vec_c_2=[] #Gibbs penalty (W/m2) for the realistic periods
Qin_vec=[] #Qin for the realistic periods. Mean value at each SST.
Qin_vec_c=[] #Qin for the realistic periods
Qin_vec_bb_Rp=[] #Qin for the single-eyewall periods
Qin_vec_bb_Rp_2=[] #Qin (W/m2) for the single-eyewall periods
Qin_vec_2=[] #Qin (W/m2) for the realistic periods. Mean value at each SST.
Qin_vec_c_2=[] #Qin (W/m2) for the realistic periods
moisture_vec=[] #Wmoist for the realistic periods. Mean value at each SST.
moisture_vec_c=[] #Wmoist for the realistic periods
moisture_vec_bb_Rp=[] #Wmoist for the single-eyewall periods
end_win_c=0 #This variable will, after all data is loaded for a given SST experiment, be equal to the total length of Wmax_vec_c, W_vec_c, etc.- and will grow each time we 
            #load data from a new SST experiment. Its final value is the same as the total number of realistic periods over all SST experiments.
end_win_vec=[] #Each entry corresponds to an SST and saves the total number of realistic periods over all SSTs up to and including the current SST, the cumulatively-growing
#value end_win_c. For example, if we have four SST experiments where the length of Wmax_vec_c, etc. is equal to 14, 15, 9, and 22, respectively, then end_win_vec will 
#contain the entries [14, 14+15, 14+15+9, 14+15+9+22].
start_win_vec=[] #Same as end_win_vec but saves the value of start_win_c, which is defined later in this code. In the example above, it would contain the values 
#[0, 14, 14+15, 14+15+9].
SST_vec_c=[] #SST values matching each entry in Wmax_vec_c, W_vec_c, etc.

for i in range(len(SSTs)): #Loop through all SST values
    SST_c=SSTs[i] #Set the current SST value
    if SST_c-floor(SST_c)==0: 
        SST_c=int(SST_c) 
    #print("SST is "+np.str(SST_c))
    end_win_c+=np.load("end_win_" +np.str(SST_c)+"_axisymm.npz" )["end_win"] #Add the length of Wmax_vec_c, etc. for this SST to the value of end_win_c (i.e. cumulative)
    end_win_c2=np.load("end_win_" +np.str(SST_c)+"_axisymm.npz" )["end_win"] #Length of Wmax_vec_c, etc. for the current SST (not cumulative)
    end_win_vec.append(end_win_c) 
    for j in range(end_win_c2): #Save the value of all MAFALDA-derived variables during each realistic period, j, of the current SST simulation
        Wmax_vec_c.append(np.load("Tds_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["Tds"].tolist())
        W_vec_c.append(np.load("addp_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["addp"].tolist())
        Wp_vec_c.append(np.load("dWp_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["dWp"].tolist())i
        Wp_vec_c_2.append(np.load("dWp_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["dWp_2"].tolist())
        WKE_vec_c.append(np.load("dWKE_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["dWKE"].tolist())
        WKE_vec_c_2.append(np.load("dWKE_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["dWKE_2"].tolist())
        dg_vec_c.append(np.load("dg_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["dg"].tolist())
        dg_vec_c_2.append(np.load("dg_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["dg_2"].tolist())
        Qin_vec_c.append(np.load("Qin_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["Qin"].tolist())
        Qin_vec_c_2.append(np.load("Qin_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["Qin_2"].tolist())
        moisture_vec_c.append(np.load("moisture_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["moisture"].tolist())
        SST_vec_c.append(SST_c) #Save the SST value corresponding to the MAFALDA-derived variables that were just saved.
    if i==0: #If we are at the first SST 
        start_win_c=0 #Initialized start_win_c, which will demark the index in Wmax_vec_c, etc., where we transition from one SST experiment to another. In other words, it 
                      #represents the total number of realistic periods in all SST experiments considered before the current SST experiment. In our earlier example, 
                      #start_win_c would first have value 0 for the first experiment, then 14, then 14+15, and finally 14+15+9.
        start_win_vec.append(start_win_c)
    else:
        start_win_c=end_win_vec[i-1] #Set start_win_c equal to end_win_c for the last SST experiment
        start_win_vec.append(start_win_c)
    #Once the MAFALDA-derived variables have been loaded from all realistic periods for the current SST experiment, calculate and save the mean value of these variables for
    #that experiment.
    Wmax_vec.append(np.mean(Wmax_vec_c[start_win_c:end_win_c]))
    W_vec.append(np.mean(W_vec_c[start_win_c:end_win_c]))
    Wp_vec.append(np.mean(Wp_vec_c[start_win_c:end_win_c]))
    Wp_vec_2.append(np.mean(Wp_vec_c_2[start_win_c:end_win_c]))
    WKE_vec.append(np.mean(WKE_vec_c[start_win_c:end_win_c]))
    WKE_vec_2.append(np.mean(WKE_vec_c_2[start_win_c:end_win_c])) 
    dg_vec.append(np.mean(dg_vec_c[start_win_c:end_win_c]))
    dg_vec_2.append(np.mean(dg_vec_c_2[start_win_c:end_win_c]))
    Qin_vec.append(np.mean(Qin_vec_c[start_win_c:end_win_c]))
    Qin_vec_2.append(np.mean(Qin_vec_c_2[start_win_c:end_win_c]))
    moisture_vec.append(np.mean(moisture_vec_c[start_win_c:end_win_c]))
    #Load the MAFALDA-derived variables calculated during the single-eyewall periods for this SST experiment.
    Wmax_vec_bb_Rp.append(np.load("Tds_" +np.str(SST_c)+"_axisymm_Rp.npz")["Tds"].tolist())
    W_vec_bb_Rp.append(np.load("addp_" +np.str(SST_c)+"_axisymm_Rp.npz")["addp"].tolist())
    Wp_vec_bb_Rp.append(np.load("dWp_" +np.str(SST_c)+"_axisymm_Rp.npz")["dWp"].tolist())
    Wp_vec_bb_Rp_2.append(np.load("dWp_" +np.str(SST_c)+"_axisymm_Rp.npz")["dWp_2"].tolist())
    WKE_vec_bb_Rp.append(np.load("dWKE_" +np.str(SST_c)+"_axisymm_Rp.npz")["dWKE"].tolist())
    WKE_vec_bb_Rp_2.append(np.load("dWKE_" +np.str(SST_c)+"_axisymm_Rp.npz")["dWKE_2"].tolist())
    dg_vec_bb_Rp.append(np.load("dg_" +np.str(SST_c)+"_axisymm_Rp.npz")["dg"].tolist())
    dg_vec_bb_Rp_2.append(np.load("dg_" +np.str(SST_c)+"_axisymm_Rp.npz")["dg_2"].tolist())
    Qin_vec_bb_Rp.append(np.load("Qin_" +np.str(SST_c)+"_axisymm_Rp.npz")["Qin"].tolist())
    Qin_vec_bb_Rp_2.append(np.load("Qin_" +np.str(SST_c)+"_axisymm_Rp.npz")["Qin_2"].tolist())
    moisture_vec_bb_Rp.append(np.load("moisture_" +np.str(SST_c)+"_axisymm_Rp.npz")["moisture"].tolist())
#Our definition of the Gibbs penalty in the main text differs by a sign from the quantity that was computed in MAFALDA_fixed_domain.ipynb and MAFALDA_manywindows.py, so we 
#correct this sign difference here.
dg_vec_c=-1*np.asarray(dg_vec_c)
dg_vec_c=dg_vec_c.tolist() #Convert to list
dg_vec_c_2=-1*np.asarray(dg_vec_c_2)
dg_vec_c_2=dg_vec_c_2.tolist()
dg_vec=-1*np.asarray(dg_vec)
dg_vec=dg_vec.tolist()
dg_vec_2=-1*np.asarray(dg_vec_2)
dg_vec_2=dg_vec_2.tolist()
dg_vec_bb_Rp=-1*np.asarray(dg_vec_bb_Rp)
dg_vec_bb_Rp=dg_vec_bb_Rp.tolist()
dg_vec_bb_Rp_2=-1*np.asarray(dg_vec_bb_Rp_2)
dg_vec_bb_Rp_2=dg_vec_bb_Rp_2.tolist()
#Calculate the trends and corresponding p-values for the results derived from the realistic periods
SST_vec_c_alt=sm.add_constant(SST_vec_c) #This step is necessary to perform a fit of the type y=ax+b, rather than of the type y=ax (i.e. a fit without an intercept). 
result_Wm=sm.OLS(Wmax_vec_c, SST_vec_c_alt).fit(cov_type='HC1') #With OLS, which is used to perform the fits for the realistic period results, the first input must be the y
                                                                #or dependent variable and the second variable must be the x or independent variable. This is different from
                                                                #in scipy.stats.linregress, which will be used to perform fits for the single-eyewall period results, where 
                                                                #the first input is the x variable and the second input is the y variable.
slope_Wm=result_Wm.params[1] #Slope
intercept_Wm=result_Wm.params[0] #Intercept
p_value_Wm=result_Wm.pvalues[1] #Slope p-value
Wmax_fit=np.poly1d([slope_Wm, intercept_Wm])(SSTs) #Predicted values of Wmax at each SST based on the fit constructed above.
#Now, we do the same thing as above for other MAFALDA- derived energetic variables
result_W=sm.OLS(W_vec_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_W=result_W.params[1] 
intercept_W=result_W.params[0] 
p_value_W=result_W.pvalues[1] 
W_fit=np.poly1d([slope_W, intercept_W])(SSTs)
result_Wp=sm.OLS(Wp_vec_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_Wp=result_Wp.params[1] 
intercept_Wp=result_Wp.params[0] 
p_value_Wp=result_Wp.pvalues[1] 
Wp_fit=np.poly1d([slope_Wp, intercept_Wp])(SSTs)
result_Wp_2=sm.OLS(Wp_vec_c_2, SST_vec_c_alt).fit(cov_type='HC1')
slope_Wp_2=result_Wp_2.params[1] 
intercept_Wp_2=result_Wp_2.params[0] 
p_value_Wp_2=result_Wp_2.pvalues[1] 
Wp_fit_2=np.poly1d([slope_Wp_2, intercept_Wp_2])(SSTs)
result_WKE=sm.OLS(WKE_vec_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_WKE=result_WKE.params[1] 
intercept_WKE=result_WKE.params[0] 
p_value_WKE=result_WKE.pvalues[1] 
WKE_fit=np.poly1d([slope_WKE, intercept_WKE])(SSTs)
result_WKE_2=sm.OLS(WKE_vec_c_2, SST_vec_c_alt).fit(cov_type='HC1')
slope_WKE_2=result_WKE_2.params[1] 
intercept_WKE_2=result_WKE_2.params[0] 
p_value_WKE_2=result_WKE_2.pvalues[1] 
WKE_fit_2=np.poly1d([slope_WKE_2, intercept_WKE_2])(SSTs)
result_dg=sm.OLS(dg_vec_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_dg=result_dg.params[1] 
intercept_dg=result_dg.params[0]
p_value_dg=result_dg.pvalues[1] 
dg_fit=np.poly1d([slope_dg, intercept_dg])(SSTs)
result_dg_2=sm.OLS(dg_vec_c_2, SST_vec_c_alt).fit(cov_type='HC1')
slope_dg_2=result_dg_2.params[1] 
intercept_dg_2=result_dg_2.params[0] 
p_value_dg_2=result_dg_2.pvalues[1] 
dg_fit_2=np.poly1d([slope_dg_2, intercept_dg_2])(SSTs)
result_Qin=sm.OLS(Qin_vec_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_Qin=result_Qin.params[1] 
intercept_Qin=result_Qin.params[0] 
p_value_Qin=result_Qin.pvalues[1] 
Qin_fit=np.poly1d([slope_Qin, intercept_Qin])(SSTs)
result_Qin_2=sm.OLS(Qin_vec_c_2, SST_vec_c_alt).fit(cov_type='HC1')
slope_Qin_2=result_Qin_2.params[1] 
intercept_Qin_2=result_Qin_2.params[0] 
p_value_Qin_2=result_Qin_2.pvalues[1] 
Qin_fit_2=np.poly1d([slope_Qin_2, intercept_Qin_2])(SSTs)
result_moisture=sm.OLS(moisture_vec_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_moisture=result_moisture.params[1] 
intercept_moisture=result_moisture.params[0] 
p_value_moisture=result_moisture.pvalues[1] 
moisture_fit=np.poly1d([slope_moisture, intercept_moisture])(SSTs)

#Calculate the trends and corresponding p-values for the results derived from the single-eyewall periods
slope_Wmax_bb_Rp, intercept_Wmax_bb_Rp, r_value_Wmax_bb_Rp, p_value_Wmax_bb_Rp, std_err = scipy.stats.linregress(SSTs, Wmax_vec_bb_Rp)
#slope_Wmax_bb_Rp is the slope of the fit, intercept_Wmax_bb_Rp is the intercept, and p_value_bb_Rp is the p-value for the slope.
Wmax_fit_bb_Rp=np.poly1d([slope_Wmax_bb_Rp, intercept_Wmax_bb_Rp])(SSTs) #Predicted values of Wmax at each SST based on the fit constructed above.
#Now, we do the same thing as above for other MAFALDA- derived energetic variables
slope_W_bb_Rp, intercept_W_bb_Rp, r_value_W_bb_Rp, p_value, std_err = scipy.stats.linregress(SSTs, W_vec_bb_Rp)
W_fit_bb_Rp=np.poly1d([slope_W_bb_Rp, intercept_W_bb_Rp])(SSTs)
slope_Wp_bb_Rp, intercept_Wp_bb_Rp, r_value_Wp_bb_Rp, p_value_Wp_bb_Rp, std_err = scipy.stats.linregress(SSTs, Wp_vec_bb_Rp)
Wp_fit_bb_Rp=np.poly1d([slope_Wp_bb_Rp, intercept_Wp_bb_Rp])(SSTs)
slope_Wp_bb_Rp_2, intercept_Wp_bb_Rp_2, r_value_Wp_bb_Rp_2, p_value_Wp_bb_Rp_2, std_err = scipy.stats.linregress(SSTs, Wp_vec_bb_Rp_2)
Wp_fit_bb_Rp_2=np.poly1d([slope_Wp_bb_Rp_2, intercept_Wp_bb_Rp_2])(SSTs)
slope_WKE_bb_Rp, intercept_WKE_bb_Rp, r_value_WKE_bb_Rp, p_value_WKE_bb_Rp, std_err = scipy.stats.linregress(SSTs, WKE_vec_bb_Rp)
WKE_fit_bb_Rp=np.poly1d([slope_WKE_bb_Rp, intercept_WKE_bb_Rp])(SSTs)
slope_WKE_bb_Rp_2, intercept_WKE_bb_Rp_2, r_value_WKE_bb_Rp_2, p_value_WKE_bb_Rp_2, std_err = scipy.stats.linregress(SSTs, WKE_vec_bb_Rp_2)
WKE_fit_bb_Rp_2=np.poly1d([slope_WKE_bb_Rp_2, intercept_WKE_bb_Rp_2])(SSTs)
slope_dg_bb_Rp, intercept_dg_bb_Rp, r_value_dg_bb_Rp, p_value_dg_bb_Rp, std_err = scipy.stats.linregress(SSTs, dg_vec_bb_Rp)
dg_fit_bb_Rp=np.poly1d([slope_dg_bb_Rp, intercept_dg_bb_Rp])(SSTs)
slope_dg_bb_Rp_2, intercept_dg_bb_Rp_2, r_value_dg_bb_Rp_2, p_value_dg_bb_Rp_2, std_err = scipy.stats.linregress(SSTs, dg_vec_bb_Rp_2)
dg_fit_bb_Rp_2=np.poly1d([slope_dg_bb_Rp_2, intercept_dg_bb_Rp_2])(SSTs)
slope_Qin_bb_Rp, intercept_Qin_bb_Rp, r_value_Qin_bb_Rp, p_value_Qin_bb_Rp, std_err = scipy.stats.linregress(SSTs, Qin_vec_bb_Rp)
Qin_fit_bb_Rp=np.poly1d([slope_Qin_bb_Rp, intercept_Qin_bb_Rp])(SSTs)
slope_Qin_bb_Rp_2, intercept_Qin_bb_Rp_2, r_value_Qin_bb_Rp_2, p_value_Qin_bb_Rp_2, std_err = scipy.stats.linregress(SSTs, Qin_vec_bb_Rp_2)
Qin_fit_bb_Rp_2=np.poly1d([slope_Qin_bb_Rp_2, intercept_Qin_bb_Rp_2])(SSTs)
slope_moist_bb_Rp, intercept_moist_bb_Rp, r_value_moist_bb_Rp, p_value_moist_bb_Rp, std_err = scipy.stats.linregress(SSTs, moisture_vec_bb_Rp)
moist_fit_bb_Rp=np.poly1d([slope_moist_bb_Rp, intercept_moist_bb_Rp])(SSTs)

#Load, for all SSTs and for both the single-eyewall and realistic periods, MAFALDA-derived efficiency and temperature quantities calculated using all MAFALDA trajectories 
#from the isentropic streamfunction. 

eta_mech_vec=[] #Mechanical efficiency for the realistic periods. Mean value at each SST
eta_mech_vec_c=[] #Mechanical efficiency for the realistic periods.
eta_mech_vec_bb_Rp=[] #Mechanical efficiency for the single-eyewall periods.
eta_c_vec=[] #Carnot efficiency for the realistic periods. Mean value at each SST
eta_c_vec_c=[] #Carnot efficiency for the realistic periods.
eta_c_vec_bb_Rp=[] #Carnot efficiency for the single-eyewall periods.
Tin_vec=[] #Input temperature (associated with the heat input) for the realistic periods. Mean value at each SST
Tin_vec_c=[] #Input temperature (associated with the heat input) for the realistic periods.
Tin_vec_bb_Rp=[] #Input temperature (associated with the heat input) for the single-eyewall periods.
Tout_vec=[] #Output temperature (associated with the heat output) for the realistic periods. Mean value at each SST
Tout_vec_c=[] #Output temperature (associated with the heat output) for the realistic periods.
Tout_vec_bb_Rp=[] #Output temperature (associated with the heat output) for the single-eyewall periods.
eta_mc_vec=[] #Ratio of mechanical to Carnot efficiency for the realistic periods. Mean value at each SST
eta_mc_vec_c=[] #Ratio of mechanical to Carnot efficiency for the realistic periods.
Tin_m_Tout_vec_c=[] #Input minus output temperature for the realistic periods.
Tin_m_Tout_vec=[] #Input minus output temperature for the realistic periods. Mean value at each SST
end_win_c=0 #Re-initialize end_win_c

for i in range(len(SSTs)):
    SST_c=SSTs[i]
    if SST_c-floor(SST_c)==0:
        SST_c=int(SST_c) 
    #print("SST is "+np.str(SST_c))
    end_win_c+=np.load("end_win_" +np.str(SST_c)+"_axisymm.npz" )["end_win"]
    end_win_c2=np.load("end_win_" +np.str(SST_c)+"_axisymm.npz" )["end_win"]
    for j in range(end_win_c2):
        eta_mech_vec_c.append(np.load("eta_mech_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["eta_mech"].tolist())
        eta_c_vec_c.append(np.load("eta_c_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["eta_c"].tolist())
        Tin_vec_c.append(np.load("eta_c_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["Tin"].tolist())
        Tout_vec_c.append(np.load("eta_c_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["Tout"].tolist())
    if i==0:
        start_win_c=0
    else:
        start_win_c=end_win_vec[i-1]
    eta_mech_vec.append(np.mean(eta_mech_vec_c[start_win_c:end_win_c]))
    eta_c_vec.append(np.mean(eta_c_vec_c[start_win_c:end_win_c]))
    Tin_vec.append(np.mean(Tin_vec_c[start_win_c:end_win_c]))
    Tout_vec.append(np.mean(Tout_vec_c[start_win_c:end_win_c]))
    eta_mc_vec_a=np.asarray(eta_mech_vec_c[start_win_c:end_win_c])/np.asarray(eta_c_vec_c[start_win_c:end_win_c])
    Tin_m_Tout_vec_a=np.asarray(Tin_vec_c[start_win_c:end_win_c])-np.asarray(Tout_vec_c[start_win_c:end_win_c])
    #Construct and add new entries to the vectors eta_mc_vec_c and Tin_m_Tout_vec_c for this SST
    for ind in np.arange(len(eta_mc_vec_a)): #Go through each entry in the array constructed above because if we just append the array to the list eta_mc_vec_c, then this 
                                             #messes up future calculations. The same is true for Tin_m_Tout_vec_c
        eta_mc_vec_c.append(eta_mc_vec_a[ind])
    for ind in np.arange(len(Tin_m_Tout_vec_a)):
        Tin_m_Tout_vec_c.append(Tin_m_Tout_vec_a[ind])
    eta_mc_vec.append(np.mean(eta_mc_vec_c[start_win_c:end_win_c]))
    Tin_m_Tout_vec.append(np.mean(Tin_m_Tout_vec_c[start_win_c:end_win_c]))
    eta_mech_vec_bb_Rp.append(np.load("eta_mech_" +np.str(SST_c)+"_axisymm_Rp.npz")["eta_mech"].tolist())
    eta_c_vec_bb_Rp.append(np.load("eta_c_" +np.str(SST_c)+"_axisymm_Rp.npz")["eta_c"].tolist())
    Tin_vec_bb_Rp.append(np.load("eta_c_" +np.str(SST_c)+"_axisymm_Rp.npz")["Tin"].tolist())
    Tout_vec_bb_Rp.append(np.load("eta_c_" +np.str(SST_c)+"_axisymm_Rp.npz")["Tout"].tolist())

#Calculate the ratio of the mechanical efficiency to the Carnot efficiency during the single-eyewall periods
eta_mc_vec_bb_Rp=np.asarray(eta_mech_vec_bb_Rp)/np.asarray(eta_c_vec_bb_Rp) 
eta_mc_vec_bb_Rp=eta_mc_vec_bb_Rp.tolist() #Convert to list

#Calculate Tin-Tout during the single-eyewall periods
Tin_m_Tout_vec_bb_Rp=np.asarray(Tin_vec_bb_Rp)-np.asarray(Tout_vec_bb_Rp)
Tin_m_Tout_vec_bb_Rp=Tin_m_Tout_vec_bb_Rp.tolist()

#Calculate the trends and corresponding p-values for the results derived from the realistic periods
result_eme=sm.OLS(eta_mech_vec_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_eme=result_eme.params[1] 
intercept_eme=result_eme.params[0] 
p_value_eme=result_eme.pvalues[1] 
eta_mech_fit=np.poly1d([slope_eme, intercept_eme])(SSTs)
result_ec=sm.OLS(eta_c_vec_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_ec=result_ec.params[1] 
intercept_ec=result_ec.params[0] 
p_value_ec=result_ec.pvalues[1] 
eta_c_fit=np.poly1d([slope_ec, intercept_ec])(SSTs)
result_emc=sm.OLS(eta_mc_vec_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_emc=result_emc.params[1] 
intercept_emc=result_emc.params[0] 
p_value_emc=result_emc.pvalues[1] 
eta_mc_fit=np.poly1d([slope_emc, intercept_emc])(SSTs)
result_ti=sm.OLS(Tin_vec_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_ti=result_ti.params[1] 
intercept_ti=result_ti.params[0] 
p_value_ti=result_ti.pvalues[1] 
Tin_fit=np.poly1d([slope_ti, intercept_ti])(SSTs)
result_to=sm.OLS(Tout_vec_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_to=result_to.params[1] 
intercept_to=result_to.params[0] 
p_value_to=result_to.pvalues[1] 
Tout_fit=np.poly1d([slope_to, intercept_to])(SSTs)
result_timo=sm.OLS(Tin_m_Tout_vec_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_timo=result_timo.params[1] 
intercept_timo=result_timo.params[0] 
p_value_timo=result_timo.pvalues[1] 
Tin_m_Tout_fit=np.poly1d([slope_timo, intercept_timo])(SSTs)

#Calculate the trends and corresponding p-values for the results derived from the single-eyewall periods
slope_eme_bb_Rp, intercept_eme_bb_Rp, r_value_eme_bb_Rp, p_value_eme_bb_Rp, std_err = scipy.stats.linregress(SSTs, eta_mech_vec_bb_Rp)
eta_mech_fit_bb_Rp=np.poly1d([slope_eme_bb_Rp, intercept_eme_bb_Rp])(SSTs)
slope_ec_bb_Rp, intercept_ec_bb_Rp, r_value_ec_bb_Rp, p_value_ec_bb_Rp, std_err = scipy.stats.linregress(SSTs, eta_c_vec_bb_Rp)
eta_c_fit_bb_Rp=np.poly1d([slope_ec_bb_Rp, intercept_ec_bb_Rp])(SSTs)
slope_emc_bb_Rp, intercept_emc_bb_Rp, r_value_emc_bb_Rp, p_value_emc_bb_Rp, std_err = scipy.stats.linregress(SSTs, eta_mc_vec_bb_Rp)
eta_mc_fit_bb_Rp=np.poly1d([slope_emc_bb_Rp, intercept_emc_bb_Rp])(SSTs)
slope_ti_bb_Rp, intercept_ti_bb_Rp, r_value_ti_bb_Rp, p_value_ti_bb_Rp, std_err = scipy.stats.linregress(SSTs, Tin_vec_bb_Rp)
Tin_fit_bb_Rp=np.poly1d([slope_ti_bb_Rp, intercept_ti_bb_Rp])(SSTs)
slope_to_bb_Rp, intercept_to_bb_Rp, r_value_to_bb_Rp, p_value_to_bb_Rp, std_err = scipy.stats.linregress(SSTs, Tout_vec_bb_Rp)
Tout_fit_bb_Rp=np.poly1d([slope_to_bb_Rp, intercept_to_bb_Rp])(SSTs)
slope_timo_bb_Rp, intercept_timo_bb_Rp, r_value_timo_bb_Rp, p_value_timo_bb_Rp, std_err = scipy.stats.linregress(SSTs, Tin_m_Tout_vec_bb_Rp)
Tin_m_Tout_fit_bb_Rp=np.poly1d([slope_timo_bb_Rp, intercept_timo_bb_Rp])(SSTs)


#Load, for all SSTs and for both the single-eyewall and realistic periods, MAFALDA-derived energetic quantities calculated using the MAFALDA trajectories corresponding to 
#either the eyewall circulation or the rainband circulation. 

#Eyewall circulation quantities
Wmax_vec_ov=[] #Wmax for the realistic periods. Mean value at each SST.
W_vec_ov=[] #W for the realistic periods. Mean value at each SST.
Wp_vec_ov=[] #Wp for the realistic periods. Mean value at each SST.
WKE_vec_ov=[] #WKE for the realistic periods. Mean value at each SST.
dg_vec_ov=[] #Gibbs penalty for the realistic periods. Mean value at each SST.
Qin_vec_ov=[] #Qin for the realistic periods. Mean value at each SST.
moisture_vec_ov=[] #Wmoist for the realistic periods. Mean value at each SST.
Wmax_vec_ov_c=[] #Wmax for the realistic periods.
W_vec_ov_c=[] #W for the realistic periods.
Wp_vec_ov_c=[] #Wp for the realistic periods.
WKE_vec_ov_c=[] #WKE for the realistic periods.
dg_vec_ov_c=[] #Gibbs penalty for the realistic periods.
Qin_vec_ov_c=[] #Qin for the realistic periods.
moisture_vec_ov_c=[] #Wmoist for the realistic periods.
Wmax_vec_ov_bb_Rp=[] #Wmax for the single-eyewall periods.
W_vec_ov_bb_Rp=[] #W for the single-eyewall periods.
Wp_vec_ov_bb_Rp=[] #Wp for the single-eyewall periods.
WKE_vec_ov_bb_Rp=[] #WKE for the single-eyewall periods.
Qin_vec_ov_bb_Rp=[] #Qin for the single-eyewall periods.
dg_vec_ov_bb_Rp=[] #Gibbs penalty for the single-eyewall periods.
moisture_vec_ov_bb_Rp=[] #Wmoist for the single-eyewall periods.
end_win_vec_ov=[] #Same as end_win_vec but for the case of the eyewall circulation. We need a separate instance of this because in some cases, no eyewall circulation is 
                  #identified and so we have fewer data points for the variables calculated for the eyewall circulation than we do for variables calculated for the rainband
                  #circulation or for all MAFALDA trajectories.
start_win_vec_ov=[] #Same as start_win_vec but for the case of the eyewall circulation. We need a separate instance of this for the same reason as we need end_win_vec_ov.
SST_vec_ov_c=[] #Same as SST_vec_c but for the case of the eyewall circulation. We need a separate instance of this for the same reason as we need end_win_vec_ov.
n_skipped=0 #This counts the number of realistic periods where there is no eyewall circulation identified for a given SST experiment. This is used to correctly define the 
            #entries to add to end_win_vec_ov and start_win_vec_ov
#Rainband circulation quantities
#Labelling is equivalent in meaning to the lists defined above.
Wmax_vec_rb=[]
W_vec_rb=[]
Wp_vec_rb=[]
WKE_vec_rb=[]
dg_vec_rb=[]
Qin_vec_rb=[]
moisture_vec_rb=[]
Wmax_vec_rb_c=[]
W_vec_rb_c=[]
Wp_vec_rb_c=[]
WKE_vec_rb_c=[]
dg_vec_rb_c=[]
Qin_vec_rb_c=[]
moisture_vec_rb_c=[]
Wmax_vec_rb_bb_Rp=[]
W_vec_rb_bb_Rp=[]
Wp_vec_rb_bb_Rp=[]
WKE_vec_rb_bb_Rp=[]
Qin_vec_rb_bb_Rp=[]
dg_vec_rb_bb_Rp=[]
moisture_vec_rb_bb_Rp=[]
end_win_c=0

#Repeat the same process for the rainband circulation-derived energetic quantities as was applied to the quantities derived from the full set of MAFALDA trajectories
for i in range(len(SSTs)):
    SST_c=SSTs[i]
    if SST_c-floor(SST_c)==0:
        SST_c=int(SST_c) 
    #print("SST is "+np.str(SST_c))
    end_win_c+=np.load("end_win_" +np.str(SST_c)+"_axisymm.npz" )["end_win"]
    end_win_c2=np.load("end_win_" +np.str(SST_c)+"_axisymm.npz" )["end_win"]
    for j in range(end_win_c2):
        Wmax_vec_rb_c.append(np.load("Tds_rb_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["Tds_rb"].tolist())
        W_vec_rb_c.append(np.load("addp_rb_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["addp_rb"].tolist())
        Wp_vec_rb_c.append(np.load("dWp_rb_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["dWp_rb"].tolist())
        WKE_vec_rb_c.append(np.load("dWKE_rb_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["dWKE_rb"].tolist())
        dg_vec_rb_c.append(np.load("dg_rb_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["dg_rb"].tolist())
        Qin_vec_rb_c.append(np.load("Qin_rb_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["Qin_rb"].tolist())
        moisture_vec_rb_c.append(np.load("moisture_rb_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["moisture_rb"].tolist()) 
    if i==0:
        start_win_c=0
    else:
        start_win_c=end_win_vec[i-1]   
    Wmax_vec_rb.append(np.mean(Wmax_vec_rb_c[start_win_c:end_win_c]))
    W_vec_rb.append(np.mean(W_vec_rb_c[start_win_c:end_win_c]))
    Wp_vec_rb.append(np.mean(Wp_vec_rb_c[start_win_c:end_win_c]))
    WKE_vec_rb.append(np.mean(WKE_vec_rb_c[start_win_c:end_win_c]))
    dg_vec_rb.append(np.mean(dg_vec_rb_c[start_win_c:end_win_c]))
    Qin_vec_rb.append(np.mean(Qin_vec_rb_c[start_win_c:end_win_c]))
    moisture_vec_rb.append(np.mean(moisture_vec_rb_c[start_win_c:end_win_c]))
    Wmax_vec_rb_bb_Rp.append(np.load("Tds_rb_" +np.str(SST_c)+"_axisymm_Rp.npz")["Tds_rb"].tolist())
    W_vec_rb_bb_Rp.append(np.load("addp_rb_" +np.str(SST_c)+"_axisymm_Rp.npz")["addp_rb"].tolist())
    Wp_vec_rb_bb_Rp.append(np.load("dWp_rb_" +np.str(SST_c)+"_axisymm_Rp.npz")["dWp_rb"].tolist())
    WKE_vec_rb_bb_Rp.append(np.load("dWKE_rb_" +np.str(SST_c)+"_axisymm_Rp.npz")["dWKE_rb"].tolist())
    dg_vec_rb_bb_Rp.append(np.load("dg_rb_" +np.str(SST_c)+"_axisymm_Rp.npz")["dg_rb"].tolist())
    Qin_vec_rb_bb_Rp.append(np.load("Qin_rb_" +np.str(SST_c)+"_axisymm_Rp.npz")["Qin_rb"].tolist())
    moisture_vec_rb_bb_Rp.append(np.load("moisture_rb_" +np.str(SST_c)+"_axisymm_Rp.npz")["moisture_rb"].tolist())

#Now we load data and construct similar vectors for energetic quantities derived from the eyewall circulation
#We begin by loading data for the single-eyewall periods
SST_vec_ov_bb_Rp=[] #Stores SST values where an eyewall circulation was identified.
for i in range(len(SSTs)):
    SST_c=SSTs[i]
    if SST_c-floor(SST_c)==0:
        SST_c=int(SST_c) 
    #print("SST is "+np.str(SST_c))
    #Load ov_flag for the single-eyewall period of this SST experiment. This has value 0 if an eyewall circulation was identified during this period, and value 1 if it was 
    #not.
    ov_flag=np.load("ov_flag_" +np.str(SST_c)+"_Rp.npz")["ov_flag"]
    if ov_flag==0: #If an eyewall circulation was identified during this period, load the values of all MAFALDA-derived energetic quantities and add them to the 
                   #corresponding vector.
        Wmax_vec_ov_bb_Rp.append(np.load("Tds_ov_" +np.str(SST_c)+"_axisymm_Rp.npz")["Tds_ov"].tolist())
        W_vec_ov_bb_Rp.append(np.load("addp_ov_" +np.str(SST_c)+"_axisymm_Rp.npz")["addp_ov"].tolist())
        Wp_vec_ov_bb_Rp.append(np.load("dWp_ov_" +np.str(SST_c)+"_axisymm_Rp.npz")["dWp_ov"].tolist())
        WKE_vec_ov_bb_Rp.append(np.load("dWKE_ov_" +np.str(SST_c)+"_axisymm_Rp.npz")["dWKE_ov"].tolist())
        dg_vec_ov_bb_Rp.append(np.load("dg_ov_" +np.str(SST_c)+"_axisymm_Rp.npz")["dg_ov"].tolist())
        Qin_vec_ov_bb_Rp.append(np.load("Qin_ov_" +np.str(SST_c)+"_axisymm_Rp.npz")["Qin_ov"].tolist())
        moisture_vec_ov_bb_Rp.append(np.load("moisture_ov_" +np.str(SST_c)+"_axisymm_Rp.npz")["moisture_ov"].tolist())
        SST_vec_ov_bb_Rp.append(float(SST_c)) #Add the current SST value to SST_vec_ov_bb_Rp


#Now, we apply to process to the realistic periods.
end_win_c=0 #Reinitialize end_win_c
for i in range(len(SSTs)):
    SST_c=SSTs[i]
    if SST_c-floor(SST_c)==0:
        SST_c=int(SST_c) 
    #print("SST is "+np.str(SST_c))
    end_win_c2=np.load("end_win_" +np.str(SST_c)+"_axisymm.npz" )["end_win"]
    n_skipped_lasti=n_skipped #Number of periods where the eyewall circulation was not detected for the last SST experiment. Equal to 0 if the current SST corresponds to 
                              #the first entry of SSTs
    n_skipped=0 #Initialize n_skipped for the current SST experiment
    for j in range(end_win_c2):
        ov_flag=np.load("ov_flag_" +np.str(SST_c)+"_"+np.str(j)+".npz")["ov_flag"] #ov_flag has value 0 if an eyewall circulation was identified for the current realistic 
                                                                                   #period
        if ov_flag==0: #If an eyewall circulation was identified during this period, load the values of all MAFALDA-derived energetic quantities and add them to the 
                       #corresponding vector.
            Wmax_vec_ov_c.append(np.load("Tds_ov_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["Tds_ov"].tolist())
            W_vec_ov_c.append(np.load("addp_ov_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["addp_ov"].tolist())
            Wp_vec_ov_c.append(np.load("dWp_ov_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["dWp_ov"].tolist())
            WKE_vec_ov_c.append(np.load("dWKE_ov_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["dWKE_ov"].tolist())
            dg_vec_ov_c.append(np.load("dg_ov_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["dg_ov"].tolist())
            Qin_vec_ov_c.append(np.load("Qin_ov_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["Qin_ov"].tolist())
            moisture_vec_ov_c.append(np.load("moisture_ov_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["moisture_ov"].tolist())
            SST_vec_ov_c.append(SST_c) #Add the current SST value to SST_vec_ov_c
        elif ov_flag==1: #If no eyewall circulation was identified during this period, increase n_skipped by 1
            n_skipped+=1
    #We now set the values of end_win_c and start_win_c for this SST. This is more complicated than before because we have skipped loading data for periods where no eyewall
    #circulation was developed, whereas previously, for cases such as the rainband circulation results, we have loaded data from all periods.
    if n_skipped==0: #If all realistic periods for this SST experiment contained an eyewall circulation
        if i==0: #If this is the first SST experiment
            #We initialize end_win_c and start_win_c as we did for cases like the rainband circulation results, since n_skipped=0 means there is no difference between this 
            #case and those as we have loaded data from all realistic periods.
            start_win_c=0 
            end_win_c=end_win_c2
            end_win_c_lasti=end_win_c #end_win_c_lasti will contain the value of end_win_c for the previous SST experiment and will be used in upcoming parts of this code 
                                      #to set the value of start_win_c. Here we initialize it.
            #print("Indices to use to take the mean are between "+np.str(start_win_c)+" and "+np.str(end_win_c))
            start_win_vec_ov.append(start_win_c)
            end_win_vec_ov.append(end_win_c)
        else: #If this is not the first SST experiment
            start_win_c=end_win_c_lasti #Use end_win_c_lasti to set the value of start_win_c
            end_win_c=end_win_c_lasti+end_win_c2 #Since no periods were skipped during the data loading for this SST experiment, the total number of periods from which we 
                                                 #have loaded data over all SST experiments so far, end_win_c, is simply the sum of its previous value, end_win_c_lasti, and
                                                 #end_win_c2, the number of total periods for this SST experiment.
            end_win_c_lasti=end_win_c #Update the value of end_win_c_lasti
            start_win_vec_ov.append(start_win_c)
            end_win_vec_ov.append(end_win_c) 
            #print("Indices to use to take the mean are between "+np.str(start_win_c)+" and "+np.str(end_win_c))
    else: #If data was not loaded for one or more realistic periods for this SST experiments because an eyewall circulation was not identified
        if i==0: #If this is the first SST experiment
            start_win_c=0 #Initialize start_win_c as usual
            end_win_c=end_win_c2-n_skipped #The initial value of end_win_c, or the number of periods from which we loaded data at this SST, is equal to the total number of 
                                           #realistic periods for this SST, end_win_c2, minus the number of periods that we did not load data from because no eyewall 
                                           #circulation was identified, n_skipped
            end_win_c_lasti=end_win_c 
            #print("Indices to use to take the mean are between "+np.str(start_win_c)+" and "+np.str(end_win_c)) #Sanity check
            start_win_vec_ov.append(start_win_c)
            end_win_vec_ov.append(end_win_c)            
        else: #If this is not the first SST experiment
            start_win_c=end_win_c_lasti #Use end_win_c_lasti to set the value of start_win_c
            end_win_c=end_win_c_lasti+end_win_c2-n_skipped #The total number of periods from which we have loaded data over all SST experiments considered so far, 
                                                           #end_win_c, is increased by the total number of periods for this SST experiment, end_win_c2, minus the number of 
                                                           #periods that we did not load data from because no eyewall circulation was identified, n_skipped
            end_win_c_lasti=end_win_c 
            start_win_vec_ov.append(start_win_c)
            end_win_vec_ov.append(end_win_c)            
            #print("Indices to use to take the mean are between "+np.str(start_win_c)+" and "+np.str(end_win_c)) #Sanity check
    #Using the values of start_win_c and end_win_c that were just set, calculate the mean value of each energetic quantity at the current SST.
    Wmax_vec_ov.append(np.mean(Wmax_vec_ov_c[start_win_c:end_win_c]))
    W_vec_ov.append(np.mean(W_vec_ov_c[start_win_c:end_win_c]))
    Wp_vec_ov.append(np.mean(Wp_vec_ov_c[start_win_c:end_win_c]))
    WKE_vec_ov.append(np.mean(WKE_vec_ov_c[start_win_c:end_win_c]))
    dg_vec_ov.append(np.mean(dg_vec_ov_c[start_win_c:end_win_c]))
    Qin_vec_ov.append(np.mean(Qin_vec_ov_c[start_win_c:end_win_c]))
    moisture_vec_ov.append(np.mean(moisture_vec_ov_c[start_win_c:end_win_c]))            

#Our definition of the Gibbs penalty in the main text differs by a sign from the quantity that was computed in MAFALDA_fixed_domain.ipynb and MAFALDA_manywindows.py, so we 
#correct this sign difference here.
dg_vec_ov_c=-1*np.asarray(dg_vec_ov_c)
dg_vec_ov_c=dg_vec_ov_c.tolist() #Convert to list 
dg_vec_ov=-1*np.asarray(dg_vec_ov)
dg_vec_ov=dg_vec_ov.tolist()
dg_vec_ov_bb_Rp=-1*np.asarray(dg_vec_ov_bb_Rp)
dg_vec_ov_bb_Rp=dg_vec_ov_bb_Rp.tolist()
dg_vec_rb_c=-1*np.asarray(dg_vec_rb_c)
dg_vec_rb_c=dg_vec_rb_c.tolist()
dg_vec_rb=-1*np.asarray(dg_vec_rb)
dg_vec_rb=dg_vec_rb.tolist()
dg_vec_rb_bb_Rp=-1*np.asarray(dg_vec_rb_bb_Rp)
dg_vec_rb_bb_Rp=dg_vec_rb_bb_Rp.tolist()

#Get trends and p-values as above, but use SST_vec_ov_c/SST_vec_ov_bb_Rp rather than SST_vec_c/SSTs as inputs to caulculate these trends and p-value for the results from 
#the eyewall circulation
#Eyewall circulation results
#Realistic periods
SST_vec_ov_c_alt=sm.add_constant(SST_vec_ov_c) 
result_Wm_ov=sm.OLS(Wmax_vec_ov_c, SST_vec_ov_c_alt).fit(cov_type='HC1')
slope_Wm_ov=result_Wm_ov.params[1] 
intercept_Wm_ov=result_Wm_ov.params[0] 
p_value_Wm_ov=result_Wm_ov.pvalues[1] 
Wmax_fit_ov=np.poly1d([slope_Wm_ov, intercept_Wm_ov])(SSTs)
result_W_ov=sm.OLS(W_vec_ov_c, SST_vec_ov_c_alt).fit(cov_type='HC1')
slope_W_ov=result_W_ov.params[1]
intercept_W_ov=result_W_ov.params[0] 
p_value_W_ov=result_W_ov.pvalues[1] 
W_fit_ov=np.poly1d([slope_W_ov, intercept_W_ov])(SSTs)
result_Wp_ov=sm.OLS(Wp_vec_ov_c, SST_vec_ov_c_alt).fit(cov_type='HC1')
slope_Wp_ov=result_Wp_ov.params[1] 
intercept_Wp_ov=result_Wp_ov.params[0] 
p_value_Wp_ov=result_Wp_ov.pvalues[1] 
Wp_fit_ov=np.poly1d([slope_Wp_ov, intercept_Wp_ov])(SSTs)
result_WKE_ov=sm.OLS(WKE_vec_ov_c, SST_vec_ov_c_alt).fit(cov_type='HC1')
slope_WKE_ov=result_WKE_ov.params[1] 
intercept_WKE_ov=result_WKE_ov.params[0] 
p_value_WKE_ov=result_WKE_ov.pvalues[1] 
WKE_fit_ov=np.poly1d([slope_WKE_ov, intercept_WKE_ov])(SSTs)
result_dg_ov=sm.OLS(dg_vec_ov_c, SST_vec_ov_c_alt).fit(cov_type='HC1')
slope_dg_ov=result_dg_ov.params[1] 
intercept_dg_ov=result_dg_ov.params[0]
p_value_dg_ov=result_dg_ov.pvalues[1] 
dg_fit_ov=np.poly1d([slope_dg_ov, intercept_dg_ov])(SSTs)
result_Qin_ov=sm.OLS(Qin_vec_ov_c, SST_vec_ov_c_alt).fit(cov_type='HC1')
slope_Qin_ov=result_Qin_ov.params[1] 
intercept_Qin_ov=result_Qin_ov.params[0] 
p_value_Qin_ov=result_Qin_ov.pvalues[1] 
Qin_fit_ov=np.poly1d([slope_Qin_ov, intercept_Qin_ov])(SSTs)
result_Wmo_ov=sm.OLS(moisture_vec_ov_c, SST_vec_ov_c_alt).fit(cov_type='HC1')
slope_Wmo_ov=result_Wmo_ov.params[1]
intercept_Wmo_ov=result_Wmo_ov.params[0] 
p_value_Wmo_ov=result_Wmo_ov.pvalues[1] 
moist_fit_ov=np.poly1d([slope_Wmo_ov, intercept_Wmo_ov])(SSTs)
#Single-eyewall periods
slope_Wm_ov_bb_Rp, intercept_Wm_ov_bb_Rp, r_value_Wm_ov_bb_Rp, p_value_Wm_ov_bb_Rp, std_err = scipy.stats.linregress(SST_vec_ov_bb_Rp, Wmax_vec_ov_bb_Rp)
Wmax_fit_ov_bb_Rp=np.poly1d([slope_Wm_ov_bb_Rp, intercept_Wm_ov_bb_Rp])(SST_vec_ov_bb_Rp)
slope_W_ov_bb_Rp, intercept_W_ov_bb_Rp, r_value_W_ov_bb_Rp, p_value_W_ov_bb_Rp, std_err = scipy.stats.linregress(SST_vec_ov_bb_Rp, W_vec_ov_bb_Rp)
W_fit_ov_bb_Rp=np.poly1d([slope_W_ov_bb_Rp, intercept_W_ov_bb_Rp])(SST_vec_ov_bb_Rp)
slope_Wp_ov_bb_Rp, intercept_Wp_ov_bb_Rp, r_value_Wp_ov_bb_Rp, p_value_Wp_ov_bb_Rp, std_err = scipy.stats.linregress(SST_vec_ov_bb_Rp, Wp_vec_ov_bb_Rp)
Wp_fit_ov_bb_Rp=np.poly1d([slope_Wp_ov_bb_Rp, intercept_Wp_ov_bb_Rp])(SST_vec_ov_bb_Rp)
slope_WKE_ov_bb_Rp, intercept_WKE_ov_bb_Rp, r_value_WKE_ov_bb_Rp, p_value_WKE_ov_bb_Rp, std_err = scipy.stats.linregress(SST_vec_ov_bb_Rp, WKE_vec_ov_bb_Rp)
WKE_fit_ov_bb_Rp=np.poly1d([slope_WKE_ov_bb_Rp, intercept_WKE_ov_bb_Rp])(SST_vec_ov_bb_Rp)
slope_dg_ov_bb_Rp, intercept_dg_ov_bb_Rp, r_value_dg_ov_bb_Rp, p_value_dg_ov_bb_Rp, std_err = scipy.stats.linregress(SST_vec_ov_bb_Rp, dg_vec_ov_bb_Rp)
dg_fit_ov_bb_Rp=np.poly1d([slope_dg_ov_bb_Rp, intercept_dg_ov_bb_Rp])(SST_vec_ov_bb_Rp)
slope_Qin_ov_bb_Rp, intercept_Qin_ov_bb_Rp, r_value_Qin_ov_bb_Rp, p_value_Qin_ov_bb_Rp, std_err = scipy.stats.linregress(SST_vec_ov_bb_Rp, Qin_vec_ov_bb_Rp)
Qin_fit_ov_bb_Rp=np.poly1d([slope_Qin_ov_bb_Rp, intercept_Qin_ov_bb_Rp])(SST_vec_ov_bb_Rp)
slope_Wmo_ov_bb_Rp, intercept_Wmo_ov_bb_Rp, r_value_Wmo_ov_bb_Rp, p_value_Wmo_ov_bb_Rp, std_err = scipy.stats.linregress(SST_vec_ov_bb_Rp, moisture_vec_ov_bb_Rp)
moist_fit_ov_bb_Rp=np.poly1d([slope_Wmo_ov_bb_Rp, intercept_Wmo_ov_bb_Rp])(SST_vec_ov_bb_Rp)

#Rainband circulation results
#Realistic periods
result_Wm_rb=sm.OLS(Wmax_vec_rb_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_Wm_rb=result_Wm_rb.params[1] 
intercept_Wm_rb=result_Wm_rb.params[0] 
p_value_Wm_rb=result_Wm_rb.pvalues[1] 
Wmax_fit_rb=np.poly1d([slope_Wm_rb, intercept_Wm_rb])(SSTs)
result_W_rb=sm.OLS(W_vec_rb_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_W_rb=result_W_rb.params[1] 
intercept_W_rb=result_W_rb.params[0] 
p_value_W_rb=result_W_rb.pvalues[1] 
W_fit_rb=np.poly1d([slope_W_rb, intercept_W_rb])(SSTs)
result_Wp_rb=sm.OLS(Wp_vec_rb_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_Wp_rb=result_Wp_rb.params[1] 
intercept_Wp_rb=result_Wp_rb.params[0] 
p_value_Wp_rb=result_Wp_rb.pvalues[1] 
Wp_fit_rb=np.poly1d([slope_Wp_rb, intercept_Wp_rb])(SSTs)
result_WKE_rb=sm.OLS(WKE_vec_rb_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_WKE_rb=result_WKE_rb.params[1] 
intercept_WKE_rb=result_WKE_rb.params[0] 
p_value_WKE_rb=result_WKE_rb.pvalues[1] 
WKE_fit_rb=np.poly1d([slope_WKE_rb, intercept_WKE_rb])(SSTs)
result_dg_rb=sm.OLS(dg_vec_rb_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_dg_rb=result_dg_rb.params[1] 
intercept_dg_rb=result_dg_rb.params[0] 
p_value_dg_rb=result_dg_rb.pvalues[1] 
dg_fit_rb=np.poly1d([slope_dg_rb, intercept_dg_rb])(SSTs)
result_Qin_rb=sm.OLS(Qin_vec_rb_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_Qin_rb=result_Qin_rb.params[1] 
intercept_Qin_rb=result_Qin_rb.params[0] 
p_value_Qin_rb=result_Qin_rb.pvalues[1] 
Qin_fit_rb=np.poly1d([slope_Qin_rb, intercept_Qin_rb])(SSTs)
result_Wmo_rb=sm.OLS(moisture_vec_rb_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_Wmo_rb=result_Wmo_rb.params[1] 
intercept_Wmo_rb=result_Wmo_rb.params[0] 
p_value_Wmo_rb=result_Wmo_rb.pvalues[1] 
moist_fit_rb=np.poly1d([slope_Wmo_rb, intercept_Wmo_rb])(SSTs)
#Single-eyewall periods
slope_Wm_rb_bb_Rp, intercept_Wm_rb_bb_Rp, r_value_Wm_rb_bb_Rp, p_value_Wm_rb_bb_Rp, std_err = scipy.stats.linregress(SSTs, Wmax_vec_rb_bb_Rp)
Wmax_fit_rb_bb_Rp=np.poly1d([slope_Wm_rb_bb_Rp, intercept_Wm_rb_bb_Rp])(SSTs)
slope_W_rb_bb_Rp, intercept_W_rb_bb_Rp, r_value_W_rb_bb_Rp, p_value_W_rb_bb_Rp, std_err = scipy.stats.linregress(SSTs, W_vec_rb_bb_Rp)
W_fit_rb_bb_Rp=np.poly1d([slope_W_rb_bb_Rp, intercept_W_rb_bb_Rp])(SSTs)
slope_Wp_rb_bb_Rp, intercept_Wp_rb_bb_Rp, r_value_Wp_rb_bb_Rp, p_value_Wp_rb_bb_Rp, std_err = scipy.stats.linregress(SSTs, Wp_vec_rb_bb_Rp)
Wp_fit_rb_bb_Rp=np.poly1d([slope_Wp_rb_bb_Rp, intercept_Wp_rb_bb_Rp])(SSTs)
slope_WKE_rb_bb_Rp, intercept_WKE_rb_bb_Rp, r_value_WKE_rb_bb_Rp, p_value_WKE_rb_bb_Rp, std_err = scipy.stats.linregress(SSTs, WKE_vec_rb_bb_Rp)
WKE_fit_rb_bb_Rp=np.poly1d([slope_WKE_rb_bb_Rp, intercept_WKE_rb_bb_Rp])(SSTs)
slope_dg_rb_bb_Rp, intercept_dg_rb_bb_Rp, r_value_dg_rb_bb_Rp, p_value_dg_rb_bb_Rp, std_err = scipy.stats.linregress(SSTs, dg_vec_rb_bb_Rp)
dg_fit_rb_bb_Rp=np.poly1d([slope_dg_rb_bb_Rp, intercept_dg_rb_bb_Rp])(SSTs)
slope_Qin_rb_bb_Rp, intercept_Qin_rb_bb_Rp, r_value_Qin_rb_bb_Rp, p_value_Qin_rb_bb_Rp, std_err = scipy.stats.linregress(SSTs, Qin_vec_rb_bb_Rp)
Qin_fit_rb_bb_Rp=np.poly1d([slope_Qin_rb_bb_Rp, intercept_Qin_rb_bb_Rp])(SSTs)
slope_Wmo_rb_bb_Rp, intercept_Wmo_rb_bb_Rp, r_value_Wmo_rb_bb_Rp, p_value_Wmo_rb_bb_Rp, std_err = scipy.stats.linregress(SSTs, moisture_vec_rb_bb_Rp)
moist_fit_rb_bb_Rp=np.poly1d([slope_Wmo_rb_bb_Rp, intercept_Wmo_rb_bb_Rp])(SSTs)

#We now perform the same procedure for MAFALDA-derived efficiency and temperature variables from the eyewall and rainband circulations.

eta_mech_vec_ov=[]
eta_c_vec_ov=[]
Tin_vec_ov=[]
Tout_vec_ov=[]
Tin_m_Tout_vec_ov=[]
eta_mc_vec_ov=[]
eta_mech_vec_ov_c=[]
eta_c_vec_ov_c=[]
Tin_vec_ov_c=[]
Tout_vec_ov_c=[]
Tin_m_Tout_vec_ov_c=[]
eta_mc_vec_ov_c=[]
eta_mech_vec_ov_bb_Rp=[]
eta_c_vec_ov_bb_Rp=[]
Tin_vec_ov_bb_Rp=[]
Tout_vec_ov_bb_Rp=[]
eta_mech_vec_rb=[]
eta_c_vec_rb=[]
Tin_vec_rb=[]
Tout_vec_rb=[]
Tin_m_Tout_vec_rb=[]
eta_mc_vec_rb=[]
eta_mech_vec_rb_c=[]
eta_c_vec_rb_c=[]
Tin_vec_rb_c=[]
Tout_vec_rb_c=[]
Tin_m_Tout_vec_rb_c=[]
eta_mc_vec_rb_c=[]
end_win_c=0
n_skipped=0 
end_win_vec_2=[]
eta_mech_vec_rb_bb_Rp=[]
eta_c_vec_rb_bb_Rp=[]
Tin_vec_rb_bb_Rp=[]
Tout_vec_rb_bb_Rp=[]

#Eyewall circulation
#Single-eyewall periods
for i in range(len(SSTs)):
    SST_c=SSTs[i]
    if SST_c-floor(SST_c)==0:
        SST_c=int(SST_c) 
    #print("SST is "+np.str(SST_c))
    ov_flag=np.load("ov_flag_" +np.str(SST_c)+"_Rp.npz")["ov_flag"]
    if ov_flag==0:
        eta_mech_vec_ov_bb_Rp.append(np.load("eta_mech_ov_" +np.str(SST_c)+"_axisymm_Rp.npz")["eta_mech_ov"].tolist())
        eta_c_vec_ov_bb_Rp.append(np.load("eta_c_ov_" +np.str(SST_c)+"_axisymm_Rp.npz")["eta_c_ov"].tolist())
        Tin_vec_ov_bb_Rp.append(np.load("eta_c_ov_" +np.str(SST_c)+"_axisymm_Rp.npz")["Tin_ov"].tolist())
        Tout_vec_ov_bb_Rp.append(np.load("eta_c_ov_" +np.str(SST_c)+"_axisymm_Rp.npz")["Tout_ov"].tolist())

#Realistic periods
for i in range(len(SSTs)):
    SST_c=SSTs[i]
    if SST_c-floor(SST_c)==0:
        SST_c=int(SST_c) 
    #print("SST is "+np.str(SST_c))
    end_win_c2=np.load("end_win_" +np.str(SST_c)+"_axisymm.npz" )["end_win"]
    n_skipped_lasti=n_skipped
    n_skipped=0
    for j in range(end_win_c2):
        ov_flag=np.load("ov_flag_" +np.str(SST_c)+"_"+np.str(j)+".npz")["ov_flag"]
        if ov_flag==0: 
            eta_mech_vec_ov_c.append(np.load("eta_mech_ov_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["eta_mech_ov"].tolist())
            eta_c_vec_ov_c.append(np.load("eta_c_ov_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["eta_c_ov"].tolist())
            Tin_vec_ov_c.append(np.load("eta_c_ov_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["Tin_ov"].tolist())
            Tout_vec_ov_c.append(np.load("eta_c_ov_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["Tout_ov"].tolist())
        elif ov_flag==1:
            n_skipped+=1 
    if n_skipped==0:
        if i==0:
            start_win_c=0
            end_win_c=end_win_c2 
            end_win_c_lasti=end_win_c
            #print("Indices to use to take the mean are between "+np.str(start_win_c)+" and "+np.str(end_win_c)) 
        else:
            start_win_c=end_win_c_lasti
            end_win_c=end_win_c_lasti+end_win_c2
            end_win_c_lasti=end_win_c
            #print("Indices to use to take the mean are between "+np.str(start_win_c)+" and "+np.str(end_win_c)) 
    else:
        if i==0:
            start_win_c=0 
            end_win_c=end_win_c2-n_skipped 
            end_win_c_lasti=end_win_c 
            #print("Indices to use to take the mean are between "+np.str(start_win_c)+" and "+np.str(end_win_c)) 
        else:
            start_win_c=end_win_c_lasti
            end_win_c=end_win_c_lasti+end_win_c2-n_skipped
            end_win_c_lasti=end_win_c
            #print("Indices to use to take the mean are between "+np.str(start_win_c)+" and "+np.str(end_win_c)) 
    eta_mech_vec_ov.append(np.mean(eta_mech_vec_ov_c[start_win_c:end_win_c]))
    eta_c_vec_ov.append(np.mean(eta_c_vec_ov_c[start_win_c:end_win_c]))
    Tin_vec_ov.append(np.mean(Tin_vec_ov_c[start_win_c:end_win_c]))
    Tout_vec_ov.append(np.mean(Tout_vec_ov_c[start_win_c:end_win_c]))
    eta_mc_vec_ov_a=np.asarray(eta_mech_vec_ov_c[start_win_c:end_win_c])/np.asarray(eta_c_vec_ov_c[start_win_c:end_win_c])
    Tin_m_Tout_vec_ov_a=np.asarray(Tin_vec_ov_c[start_win_c:end_win_c])-np.asarray(Tout_vec_ov_c[start_win_c:end_win_c])
    for ind in np.arange(len(eta_mc_vec_ov_a)): 
        eta_mc_vec_ov_c.append(eta_mc_vec_ov_a[ind])
    for ind in np.arange(len(Tin_m_Tout_vec_ov_a)):
        Tin_m_Tout_vec_ov_c.append(Tin_m_Tout_vec_ov_a[ind])
    eta_mc_vec_ov.append(np.mean(eta_mc_vec_ov_c[start_win_c:end_win_c]))
    Tin_m_Tout_vec_ov.append(np.mean(Tin_m_Tout_vec_ov_c[start_win_c:end_win_c]))

#Rainband circulation- both realistic and single-eyewall periods 
end_win_c=0 #Re-initialize
for i in range(len(SSTs)):
    SST_c=SSTs[i]
    if SST_c-floor(SST_c)==0:
        SST_c=int(SST_c)
    #print("SST is "+np.str(SST_c))
    #Realistic periods
    end_win_c+=np.load("end_win_" +np.str(SST_c)+"_axisymm.npz" )["end_win"]
    end_win_c2=np.load("end_win_" +np.str(SST_c)+"_axisymm.npz" )["end_win"]
    for j in range(end_win_c2):
        eta_mech_vec_rb_c.append(np.load("eta_mech_rb_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["eta_mech_rb"].tolist())
        eta_c_vec_rb_c.append(np.load("eta_c_rb_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["eta_c_rb"].tolist())
        Tin_vec_rb_c.append(np.load("eta_c_rb_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["Tin_rb"].tolist())
        Tout_vec_rb_c.append(np.load("eta_c_rb_" +np.str(SST_c)+"_"+np.str(j)+"_axisymm.npz")["Tout_rb"].tolist())
    if i==0:
        start_win_c=0
    else:
        start_win_c=end_win_vec[i-1]
    eta_mech_vec_rb.append(np.mean(eta_mech_vec_rb_c[start_win_c:end_win_c]))
    eta_c_vec_rb.append(np.mean(eta_c_vec_rb_c[start_win_c:end_win_c]))
    Tin_vec_rb.append(np.mean(Tin_vec_rb_c[start_win_c:end_win_c]))
    Tout_vec_rb.append(np.mean(Tout_vec_rb_c[start_win_c:end_win_c]))
    eta_mc_vec_rb_a=np.asarray(eta_mech_vec_rb_c[start_win_c:end_win_c])/np.asarray(eta_c_vec_rb_c[start_win_c:end_win_c])
    Tin_m_Tout_vec_rb_a=np.asarray(Tin_vec_rb_c[start_win_c:end_win_c])-np.asarray(Tout_vec_rb_c[start_win_c:end_win_c])
    for ind in np.arange(len(eta_mc_vec_rb_a)):
        eta_mc_vec_rb_c.append(eta_mc_vec_rb_a[ind])
    for ind in np.arange(len(Tin_m_Tout_vec_rb_a)):
        Tin_m_Tout_vec_rb_c.append(Tin_m_Tout_vec_rb_a[ind])
    eta_mc_vec_rb.append(np.mean(eta_mc_vec_rb_c[start_win_c:end_win_c]))
    Tin_m_Tout_vec_rb.append(np.mean(Tin_m_Tout_vec_rb_c[start_win_c:end_win_c]))
    #Single-eyewall periods
    eta_mech_vec_rb_bb_Rp.append(np.load("eta_mech_rb_" +np.str(SST_c)+"_axisymm_Rp.npz")["eta_mech_rb"].tolist())
    eta_c_vec_rb_bb_Rp.append(np.load("eta_c_rb_" +np.str(SST_c)+"_axisymm_Rp.npz")["eta_c_rb"].tolist())
    Tin_vec_rb_bb_Rp.append(np.load("eta_c_rb_" +np.str(SST_c)+"_axisymm_Rp.npz")["Tin_rb"].tolist())
    Tout_vec_rb_bb_Rp.append(np.load("eta_c_rb_" +np.str(SST_c)+"_axisymm_Rp.npz")["Tout_rb"].tolist())

#Calculate the ratio of eta_mech to eta_c for the eyewall and rainband circulations during the single-eyewall periods
eta_mc_vec_ov_bb_Rp=np.asarray(eta_mech_vec_ov_bb_Rp)/np.asarray(eta_c_vec_ov_bb_Rp)   
eta_mc_vec_ov_bb_Rp=eta_mc_vec_ov_bb_Rp.tolist()
eta_mc_vec_rb_bb_Rp=np.asarray(eta_mech_vec_rb_bb_Rp)/np.asarray(eta_c_vec_rb_bb_Rp)  
eta_mc_vec_rb_bb_Rp=eta_mc_vec_rb_bb_Rp.tolist()

#Calculate input minus output temperature for the eyewall and rainband circulations during the single-eyewall periods
Tin_m_Tout_vec_ov_bb_Rp=np.asarray(Tin_vec_ov_bb_Rp)-np.asarray(Tout_vec_ov_bb_Rp)
Tin_m_Tout_vec_ov_bb_Rp=Tin_m_Tout_vec_ov_bb_Rp.tolist()
Tin_m_Tout_vec_rb_bb_Rp=np.asarray(Tin_vec_rb_bb_Rp)-np.asarray(Tout_vec_rb_bb_Rp)
Tin_m_Tout_vec_rb_bb_Rp=Tin_m_Tout_vec_rb_bb_Rp.tolist()

#Get trends and p-values
#Eyewall circulation results
#Realistic periods
result_eme_ov=sm.OLS(eta_mech_vec_ov_c, SST_vec_ov_c_alt).fit(cov_type='HC1')
slope_eme_ov=result_eme_ov.params[1] 
intercept_eme_ov=result_eme_ov.params[0]
p_value_eme_ov=result_eme_ov.pvalues[1] 
eta_mech_fit_ov=np.poly1d([slope_eme_ov, intercept_eme_ov])(SSTs)
result_ec_ov=sm.OLS(eta_c_vec_ov_c, SST_vec_ov_c_alt).fit(cov_type='HC1')
slope_ec_ov=result_ec_ov.params[1] 
intercept_ec_ov=result_ec_ov.params[0] 
p_value_ec_ov=result_ec_ov.pvalues[1] 
eta_c_fit_ov=np.poly1d([slope_ec_ov, intercept_ec_ov])(SSTs)
result_emc_ov=sm.OLS(eta_mc_vec_ov_c, SST_vec_ov_c_alt).fit(cov_type='HC1')
slope_emc_ov=result_emc_ov.params[1]
intercept_emc_ov=result_emc_ov.params[0] 
p_value_emc_ov=result_emc_ov.pvalues[1] 
eta_mc_fit_ov=np.poly1d([slope_emc_ov, intercept_emc_ov])(SSTs)
result_ti_ov=sm.OLS(Tin_vec_ov_c, SST_vec_ov_c_alt).fit(cov_type='HC1')
slope_ti_ov=result_ti_ov.params[1] 
intercept_ti_ov=result_ti_ov.params[0] 
p_value_ti_ov=result_ti_ov.pvalues[1] 
Tin_fit_ov=np.poly1d([slope_ti_ov, intercept_ti_ov])(SSTs)
result_to_ov=sm.OLS(Tout_vec_ov_c, SST_vec_ov_c_alt).fit(cov_type='HC1')
slope_to_ov=result_to_ov.params[1] 
intercept_to_ov=result_to_ov.params[0] 
p_value_to_ov=result_to_ov.pvalues[1] 
Tout_fit_ov=np.poly1d([slope_to_ov, intercept_to_ov])(SSTs)
result_timo_ov=sm.OLS(Tin_m_Tout_vec_ov_c, SST_vec_ov_c_alt).fit(cov_type='HC1')
slope_timo_ov=result_timo_ov.params[1] 
intercept_timo_ov=result_timo_ov.params[0] 
p_value_timo_ov=result_timo_ov.pvalues[1] 
Tin_m_Tout_fit_ov=np.poly1d([slope_timo_ov, intercept_timo_ov])(SSTs)
#Single-eyewall periods
slope_eme_ov_bb_Rp, intercept_eme_ov_bb_Rp, r_value_eme_ov_bb_Rp, p_value_eme_ov_bb_Rp, std_err = scipy.stats.linregress(SST_vec_ov_bb_Rp, eta_mech_vec_ov_bb_Rp)
eta_mech_fit_ov_bb_Rp=np.poly1d([slope_eme_ov_bb_Rp, intercept_eme_ov_bb_Rp])(SST_vec_ov_bb_Rp)
slope_ec_ov_bb_Rp, intercept_ec_ov_bb_Rp, r_value_ec_ov_bb_Rp, p_value_ec_ov_bb_Rp, std_err = scipy.stats.linregress(SST_vec_ov_bb_Rp, eta_c_vec_ov_bb_Rp)
eta_c_fit_ov_bb_Rp=np.poly1d([slope_ec_ov_bb_Rp, intercept_ec_ov_bb_Rp])(SST_vec_ov_bb_Rp)
slope_emc_ov_bb_Rp, intercept_emc_ov_bb_Rp, r_value_emc_ov_bb_Rp, p_value_emc_ov_bb_Rp, std_err = scipy.stats.linregress(SST_vec_ov_bb_Rp, eta_mc_vec_ov_bb_Rp)
eta_mc_fit_ov_bb_Rp=np.poly1d([slope_emc_ov_bb_Rp, intercept_emc_ov_bb_Rp])(SST_vec_ov_bb_Rp)
slope_ti_ov_bb_Rp, intercept_ti_ov_bb_Rp, r_value_ti_ov_bb_Rp, p_value_ti_ov_bb_Rp, std_err = scipy.stats.linregress(SST_vec_ov_bb_Rp, Tin_vec_ov_bb_Rp)
Tin_fit_ov_bb_Rp=np.poly1d([slope_ti_ov_bb_Rp, intercept_ti_ov_bb_Rp])(SST_vec_ov_bb_Rp)
slope_to_ov_bb_Rp, intercept_to_ov_bb_Rp, r_value_to_ov_bb_Rp, p_value_to_ov_bb_Rp, std_err = scipy.stats.linregress(SST_vec_ov_bb_Rp, Tout_vec_ov_bb_Rp)
Tout_fit_ov_bb_Rp=np.poly1d([slope_to_ov_bb_Rp, intercept_to_ov_bb_Rp])(SST_vec_ov_bb_Rp)
slope_timo_ov_bb_Rp, intercept_timo_ov_bb_Rp, r_value_timo_ov_bb_Rp, p_value_timo_ov_bb_Rp, std_err = scipy.stats.linregress(SST_vec_ov_bb_Rp, Tin_m_Tout_vec_ov_bb_Rp)
Tin_m_Tout_fit_ov_bb_Rp=np.poly1d([slope_timo_ov_bb_Rp, intercept_timo_ov_bb_Rp])(SST_vec_ov_bb_Rp)

#Rainband circulation results
#Realistic periods
result_eme_rb=sm.OLS(eta_mech_vec_rb_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_eme_rb=result_eme_rb.params[1] 
intercept_eme_rb=result_eme_rb.params[0] 
p_value_eme_rb=result_eme_rb.pvalues[1] 
eta_mech_fit_rb=np.poly1d([slope_eme_rb, intercept_eme_rb])(SSTs)
result_ec_rb=sm.OLS(eta_c_vec_rb_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_ec_rb=result_ec_rb.params[1] 
intercept_ec_rb=result_ec_rb.params[0] 
p_value_ec_rb=result_ec_rb.pvalues[1] 
eta_c_fit_rb=np.poly1d([slope_ec_rb, intercept_ec_rb])(SSTs)
result_emc_rb=sm.OLS(eta_mc_vec_rb_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_emc_rb=result_emc_rb.params[1] 
intercept_emc_rb=result_emc_rb.params[0] 
p_value_emc_rb=result_emc_rb.pvalues[1] 
eta_mc_fit_rb=np.poly1d([slope_emc_rb, intercept_emc_rb])(SSTs)
result_ti_rb=sm.OLS(Tin_vec_rb_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_ti_rb=result_ti_rb.params[1] 
intercept_ti_rb=result_ti_rb.params[0] 
p_value_ti_rb=result_ti_rb.pvalues[1] 
Tin_fit_rb=np.poly1d([slope_ti_rb, intercept_ti_rb])(SSTs)
result_to_rb=sm.OLS(Tout_vec_rb_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_to_rb=result_to_rb.params[1]
intercept_to_rb=result_to_rb.params[0] 
p_value_to_rb=result_to_rb.pvalues[1] 
Tout_fit_rb=np.poly1d([slope_to_rb, intercept_to_rb])(SSTs)
result_timo_rb=sm.OLS(Tin_m_Tout_vec_rb_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_timo_rb=result_timo_rb.params[1] 
intercept_timo_rb=result_timo_rb.params[0] 
p_value_timo_rb=result_timo_rb.pvalues[1] 
Tin_m_Tout_fit_rb=np.poly1d([slope_timo_rb, intercept_timo_rb])(SSTs)
#Single-eyewall periods
slope_eme_rb_bb_Rp, intercept_eme_rb_bb_Rp, r_value_eme_rb_bb_Rp, p_value_eme_rb_bb_Rp, std_err = scipy.stats.linregress(SSTs, eta_mech_vec_rb_bb_Rp)
eta_mech_fit_rb_bb_Rp=np.poly1d([slope_eme_rb_bb_Rp, intercept_eme_rb_bb_Rp])(SSTs)
slope_ec_rb_bb_Rp, intercept_ec_rb_bb_Rp, r_value_ec_rb_bb_Rp, p_value_ec_rb_bb_Rp, std_err = scipy.stats.linregress(SSTs, eta_c_vec_rb_bb_Rp)
eta_c_fit_rb_bb_Rp=np.poly1d([slope_ec_rb_bb_Rp, intercept_ec_rb_bb_Rp])(SSTs)
slope_emc_rb_bb_Rp, intercept_emc_rb_bb_Rp, r_value_emc_rb_bb_Rp, p_value_emc_rb_bb_Rp, std_err = scipy.stats.linregress(SSTs, eta_mc_vec_rb_bb_Rp)
eta_mc_fit_rb_bb_Rp=np.poly1d([slope_emc_rb_bb_Rp, intercept_emc_rb_bb_Rp])(SSTs)
slope_ti_rb_bb_Rp, intercept_ti_rb_bb_Rp, r_value_ti_rb_bb_Rp, p_value_ti_rb_bb_Rp, std_err = scipy.stats.linregress(SSTs, Tin_vec_rb_bb_Rp)
Tin_fit_rb_bb_Rp=np.poly1d([slope_ti_rb_bb_Rp, intercept_ti_rb_bb_Rp])(SSTs)
slope_to_rb_bb_Rp, intercept_to_rb_bb_Rp, r_value_to_rb_bb_Rp, p_value_to_rb_bb_Rp, std_err = scipy.stats.linregress(SSTs, Tout_vec_rb_bb_Rp)
Tout_fit_rb_bb_Rp=np.poly1d([slope_to_rb_bb_Rp, intercept_to_rb_bb_Rp])(SSTs)
slope_timo_rb_bb_Rp, intercept_timo_rb_bb_Rp, r_value_timo_rb_bb_Rp, p_value_timo_rb_bb_Rp, std_err = scipy.stats.linregress(SSTs, Tin_m_Tout_vec_rb_bb_Rp)
Tin_m_Tout_fit_rb_bb_Rp=np.poly1d([slope_timo_rb_bb_Rp, intercept_timo_rb_bb_Rp])(SSTs)


#Here, we calculate the trend (and p-value) in the number of "eyewall circulation" levels of the isentropic streamfunction
#for the realistic periods
ol_vec=[]
ol_vec_c=[]
end_win_c=0
for i in range(len(SSTs)):
    SST_c=SSTs[i]
    if SST_c-floor(SST_c)==0:
        SST_c=int(SST_c) 
    #print("SST is "+np.str(SST_c))
    end_win_c+=np.load("end_win_" +np.str(SST_c)+"_axisymm.npz" )["end_win"]
    end_win_c2=np.load("end_win_" +np.str(SST_c)+"_axisymm.npz" )["end_win"]
    for j in range(end_win_c2):
        ol_vec_c.append(np.load("ov_levels_"+np.str(SST_c)+"_"+np.str(j)+".npz")["nlevels"].tolist())
    if i==0:
        start_win_c=0
    else:
        start_win_c=end_win_vec[i-1]
    ol_vec.append(np.mean(ol_vec_c[start_win_c:end_win_c]))
result_ol=sm.OLS(ol_vec_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_ol=result_ol.params[1] 
intercept_ol=result_ol.params[0] 
p_value_ol=result_ol.pvalues[1] 
ol_fit=np.poly1d([slope_ol, intercept_ol])(SSTs)


#Now, we construct vectors and derive trends and p-values as above for quantities related to the MAFALDA-derived variables:
#Maximum tangential wind speed-derived kinetic energy per unit mass of dry air
#Single-eyewall periods
KE_vec_bb_Rp=[]
for i in range(len(SSTs)):
    SST_c=SSTs[i]
    if SST_c-floor(SST_c)==0:
        SST_c=int(SST_c) 
    #print("SST is "+np.str(SST_c))
    KE_vec_bb_Rp.append(np.load("KE_pm_" +np.str(SST_c)+"_axisymm_Rp.npz")["KE_pm"].tolist())
slope_ke_bb_Rp, intercept_ke_bb_Rp, r_value_ke_bb_Rp, p_value_ke_bb_Rp, std_err = scipy.stats.linregress(SSTs, KE_vec_bb_Rp)
KE_fit_bb_Rp=np.poly1d([slope_ke_bb_Rp, intercept_ke_bb_Rp])(SSTs)

#Realistic periods
KE_vec=[]
KE_vec_c=[]
end_win_c=0
for i in range(len(SSTs)):
    SST_c=SSTs[i]
    if SST_c-floor(SST_c)==0:
        SST_c=int(SST_c) 
    #print("SST is "+np.str(SST_c))
    end_win_c+=np.load("end_win_" +np.str(SST_c)+"_axisymm.npz" )["end_win"]
    end_win_c2=np.load("end_win_" +np.str(SST_c)+"_axisymm.npz" )["end_win"]
    for j in range(end_win_c2):
        KE_vec_c.append(np.load("KE_pm_" +np.str(SST_c)+"_"+np.str(j)+".npz")["KE_pm"].tolist())
    if i==0:
        start_win_c=0
    else:
        start_win_c=end_win_vec[i-1]
    KE_vec.append(np.mean(KE_vec_c[start_win_c:end_win_c]))
result_ke=sm.OLS(KE_vec_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_ke=result_ke.params[1] 
intercept_ke=result_ke.params[0] 
p_value_ke=result_ke.pvalues[1] 
KE_fit=np.poly1d([slope_ke, intercept_ke])(SSTs)

#Potential intensity-derived kinetic energy per unit mass of dry air
KE_pi_vec=[]
for i in range(len(SSTs)):
    SST_c=SSTs[i]
    if SST_c-floor(SST_c)==0:
        SST_c=int(SST_c)
    KE_pi_vec.append(np.load("KE_pi_" +np.str(SST_c)+"_axisymm_Rp.npz")["KE_pi"].tolist())
slope_kpi_bb_Rp, intercept_kpi_bb_Rp, r_value_kpi_bb_Rp, p_value_kpi_bb_Rp, std_err = scipy.stats.linregress(SSTs, KE_pi_vec)
KE_pi_fit=np.poly1d([slope_kpi_bb_Rp, intercept_kpi_bb_Rp])(SSTs)

#Integrated kinetic energy
#Single-eyewall periods
IKE_vec_bb_Rp=[]
for i in range(len(SSTs)):
    SST_c=SSTs[i]
    if SST_c-floor(SST_c)==0:
        SST_c=int(SST_c) 
    #print("SST is "+np.str(SST_c))
    IKE_vec_bb_Rp.append(np.load("IKE_" +np.str(SST_c)+"_axisymm_Rp.npz")["IKE"].tolist())
slope_ike_bb_Rp, intercept_ike_bb_Rp, r_value_ike_bb_Rp, p_value_ike_bb_Rp, std_err = scipy.stats.linregress(SSTs, IKE_vec_bb_Rp)
IKE_fit_bb_Rp=np.poly1d([slope_ike_bb_Rp, intercept_ike_bb_Rp])(SSTs)

#Realistic periods
IKE_vec=[]
IKE_vec_c=[]
end_win_c=0
for i in range(len(SSTs)):
    SST_c=SSTs[i]
    if SST_c-floor(SST_c)==0:
        SST_c=int(SST_c)
    #print("SST is "+np.str(SST_c))
    end_win_c+=np.load("end_win_" +np.str(SST_c)+"_axisymm.npz" )["end_win"]
    end_win_c2=np.load("end_win_" +np.str(SST_c)+"_axisymm.npz" )["end_win"]
    for j in range(end_win_c2):
        IKE_vec_c.append(np.load("IKE_" +np.str(SST_c)+"_"+np.str(j)+".npz")["IKE"].tolist())
    if i==0:
        start_win_c=0
    else:
        start_win_c=end_win_vec[i-1]
    IKE_vec.append(np.mean(IKE_vec_c[start_win_c:end_win_c]))
result_ike=sm.OLS(IKE_vec_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_ike=result_ike.params[1]
intercept_ike=result_ike.params[0] 
p_value_ike=result_ike.pvalues[1] 
IKE_fit=np.poly1d([slope_ike, intercept_ike])(SSTs)

#Surface precipitation rate
#Single-eyewall periods
pr_vec_bb_Rp=[]
for i in range(len(SSTs)):
    SST_c=SSTs[i]
    if SST_c-floor(SST_c)==0:
        SST_c=int(SST_c) 
    #print("SST is "+np.str(SST_c))
    pr_vec_bb_Rp.append(np.load("pr_" +np.str(SST_c)+"_axisymm_Rp.npz")["pr"].tolist())
slope_pr_bb_Rp, intercept_pr_bb_Rp, r_value_pr_bb_Rp, p_value_pr_bb_Rp, std_err = scipy.stats.linregress(SSTs, pr_vec_bb_Rp)
pr_fit_bb_Rp=np.poly1d([slope_pr_bb_Rp, intercept_pr_bb_Rp])(SSTs)
#Realistic periods
pr_vec=[]
pr_vec_c=[]
end_win_c=0
for i in range(len(SSTs)):
    SST_c=SSTs[i]
    if SST_c-floor(SST_c)==0:
        SST_c=int(SST_c) 
    #print("SST is "+np.str(SST_c))
    end_win_c+=np.load("end_win_" +np.str(SST_c)+"_axisymm.npz" )["end_win"]
    end_win_c2=np.load("end_win_" +np.str(SST_c)+"_axisymm.npz" )["end_win"]
    for j in range(end_win_c2):
        pr_vec_c.append(np.load("pr_" +np.str(SST_c)+"_"+np.str(j)+".npz")["pr"].tolist())
    if i==0:
        start_win_c=0
    else:
        start_win_c=end_win_vec[i-1]
    pr_vec.append(np.mean(pr_vec_c[start_win_c:end_win_c]))
result_pr=sm.OLS(pr_vec_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_pr=result_pr.params[1] 
intercept_pr=result_pr.params[0]
p_value_pr=result_pr.pvalues[1] 
pr_fit=np.poly1d([slope_pr, intercept_pr])(SSTs)

#Surface sensible, latent, and total heat flux
#Single-eyewall periods
SHF_vec_bb_Rp=[] #Sensible heat flux
LHF_vec_bb_Rp=[] #Latent heat flux
THF_vec_bb_Rp=[] #Total heat flux
for i in range(len(SSTs)):
    SST_c=SSTs[i]
    if SST_c-floor(SST_c)==0:
        SST_c=int(SST_c) 
    #print("SST is "+np.str(SST_c))
    SHF_vec_bb_Rp.append(np.load("Heat_flux_" +np.str(SST_c)+"_axisymm_Rp.npz")["shflux"].tolist())
    LHF_vec_bb_Rp.append(np.load("Heat_flux_" +np.str(SST_c)+"_axisymm_Rp.npz")["lhflux"].tolist())
    THF_vec_bb_Rp.append(np.load("Heat_flux_" +np.str(SST_c)+"_axisymm_Rp.npz")["totflux"].tolist())
slope_sh_bb_Rp, intercept_sh_bb_Rp, r_value_sh_bb_Rp, p_value_sh_bb_Rp, std_err = scipy.stats.linregress(SSTs, SHF_vec_bb_Rp)
SHF_fit_bb_Rp=np.poly1d([slope_sh_bb_Rp, intercept_sh_bb_Rp])(SSTs)
slope_lh_bb_Rp, intercept_lh_bb_Rp, r_value_lh_bb_Rp, p_value_lh_bb_Rp, std_err = scipy.stats.linregress(SSTs, LHF_vec_bb_Rp)
LHF_fit_bb_Rp=np.poly1d([slope_lh_bb_Rp, intercept_lh_bb_Rp])(SSTs)
slope_th_bb_Rp, intercept_th_bb_Rp, r_value_th_bb_Rp, p_value_th_bb_Rp, std_err = scipy.stats.linregress(SSTs, THF_vec_bb_Rp)
THF_fit_bb_Rp=np.poly1d([slope_th_bb_Rp, intercept_th_bb_Rp])(SSTs)

#Realistic periods
end_win_c=0
#Sensible heat flux:
SHF_vec=[] 
SHF_vec_c=[]
#Latent heat flux:
LHF_vec=[]
LHF_vec_c=i[]
#Total heat flux:
THF_vec=[]
THF_vec_c=[]
for i in range(len(SSTs)):
    SST_c=SSTs[i]
    if SST_c-floor(SST_c)==0:
        SST_c=int(SST_c) 
    #print("SST is "+np.str(SST_c))
    end_win_c+=np.load("end_win_" +np.str(SST_c)+"_axisymm.npz" )["end_win"]
    end_win_c2=np.load("end_win_" +np.str(SST_c)+"_axisymm.npz" )["end_win"]
    for j in range(end_win_c2):
        SHF_vec_c.append(np.load("Heat_flux_" +np.str(SST_c)+"_"+np.str(j)+".npz")["shflux"].tolist())
        LHF_vec_c.append(np.load("Heat_flux_" +np.str(SST_c)+"_"+np.str(j)+".npz")["lhflux"].tolist())
        THF_vec_c.append(np.load("Heat_flux_" +np.str(SST_c)+"_"+np.str(j)+".npz")["totflux"].tolist())
    if i==0:
        start_win_c=0
    else:
        start_win_c=end_win_vec[i-1]
    SHF_vec.append(np.mean(SHF_vec_c[start_win_c:end_win_c]))
    LHF_vec.append(np.mean(LHF_vec_c[start_win_c:end_win_c]))
    THF_vec.append(np.mean(THF_vec_c[start_win_c:end_win_c]))
result_sh=sm.OLS(SHF_vec_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_sh=result_sh.params[1] 
intercept_sh=result_sh.params[0] 
p_value_sh=result_sh.pvalues[1] 
SHF_fit=np.poly1d([slope_sh, intercept_sh])(SSTs)
result_lh=sm.OLS(LHF_vec_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_lh=result_lh.params[1] 
intercept_lh=result_lh.params[0] 
p_value_lh=result_lh.pvalues[1] 
LHF_fit=np.poly1d([slope_lh, intercept_lh])(SSTs)
result_th=sm.OLS(THF_vec_c, SST_vec_c_alt).fit(cov_type='HC1')
slope_th=result_th.params[1] 
intercept_th=result_th.params[0] 
p_value_th=result_th.pvalues[1] 
THF_fit=np.poly1d([slope_th, intercept_th])(SSTs)



#Save data necessary to make plots for figures 4-9 of the main text:
np.savez("General_inputs_Figs.npz", SSTs=SSTs, SST_vec_ov_bb_Rp=SST_vec_ov_bb_Rp, end_win_vec=end_win_vec, end_win_vec_ov=end_win_vec_ov, start_win_vec=start_win_vec, start_win_vec_ov=start_win_vec_ov)
np.savez("Fig5_top.npz", Wmax_vec_c=Wmax_vec_c, Wmax_fit=Wmax_fit, Wmax_vec_ov_c=Wmax_vec_ov_c, Wmax_vec_rb_c=Wmax_vec_rb_c, Wmax_fit_ov=Wmax_fit_ov, Wmax_fit_rb=Wmax_fit_rb, WKE_vec_c=WKE_vec_c, WKE_fit=WKE_fit, WKE_vec_ov_c=WKE_vec_ov_c, WKE_vec_rb_c=WKE_vec_rb_c, WKE_fit_ov=WKE_fit_ov, WKE_fit_rb=WKE_fit_rb, Wmoist_vec_c=moisture_vec_c, Wmoist_fit=moisture_fit, Wmoist_vec_ov_c=moisture_vec_ov_c, Wmoist_vec_rb_c=moisture_vec_rb_c, Wmoist_fit_ov=moist_fit_ov, Wmoist_fit_rb=moist_fit_rb)
np.savez("Fig5_bot.npz", eta_c_vec_c=eta_c_vec_c, eta_c_fit=eta_c_fit, eta_c_vec_ov_c=eta_c_vec_ov_c, eta_c_vec_rb_c=eta_c_vec_rb_c, eta_c_fit_ov=eta_c_fit_ov, eta_c_fit_rb=eta_c_fit_rb, eta_mech_vec_c=eta_mech_vec_c, eta_mech_fit=eta_mech_fit, eta_mech_vec_ov_c=eta_mech_vec_ov_c, eta_mech_vec_rb_c=eta_mech_vec_rb_c, eta_mech_fit_ov=eta_mech_fit_ov, eta_mech_fit_rb=eta_mech_fit_rb, Qin_vec_c=Qin_vec_c, Qin_fit=Qin_fit, Qin_vec_ov_c=Qin_vec_ov_c, Qin_vec_rb_c=Qin_vec_rb_c, Qin_fit_ov=Qin_fit_ov, Qin_fit_rb=Qin_fit_rb)
np.savez("Fig6.npz", Wp_vec_ov=Wp_vec_ov, Wp_vec=Wp_vec, Wp_vec_rb=Wp_vec_rb, Wp_fit_ov=Wp_fit_ov, Wp_fit=Wp_fit, Wp_fit_rb=Wp_fit_rb, Wp_vec_ov_c=Wp_vec_ov_c, Wp_vec_c=Wp_vec_c, Wp_vec_rb_c=Wp_vec_rb_c, dg_vec_ov=dg_vec_ov, dg_vec=dg_vec, dg_vec_rb=dg_vec_rb, dg_fit_ov=dg_fit_ov, dg_fit=dg_fit, dg_fit_rb=dg_fit_rb, dg_vec_ov_c=dg_vec_ov_c, dg_vec_c=dg_vec_c, dg_vec_rb_c=dg_vec_rb_c)
np.savez("Fig7_top.npz", KE_pi_vec=KE_pi_vec, KE_pi_fit=KE_pi_fit, pr_fit=pr_fit, pr_vec_c=pr_vec_c, KE_vec_c=KE_vec_c, KE_fit=KE_fit, IKE_vec_c=IKE_vec_c, IKE_fit=IKE_fit)
np.savez("Fig7_bot.npz", LHF_vec_c=LHF_vec_c, LHF_fit=LHF_fit, SHF_vec_c=SHF_vec_c, SHF_fit=SHF_fit, THF_vec_c=THF_vec_c, THF_fit=THF_fit, eta_mc_fit=eta_mc_fit, eta_mc_vec_c=eta_mc_vec_c, eta_mc_fit_ov=eta_mc_fit_ov, eta_mc_vec_ov_c=eta_mc_vec_ov_c, eta_mc_fit_rb=eta_mc_fit_rb, eta_mc_vec_rb_c=eta_mc_vec_rb_c, Tin_fit=Tin_fit, Tin_vec_c=Tin_vec_c, Tout_fit=Tout_fit, Tout_vec_c=Tout_vec_c, Tin_m_Tout_vec_c=Tin_m_Tout_vec_c, Tin_m_Tout_fit=Tin_m_Tout_fit)
np.savez("S_Mat_Fig_1a.npz", Wmax_vec_bb_Rp=Wmax_vec_bb_Rp, Wmax_fit_bb_Rp=Wmax_fit_bb_Rp, Wmax_vec_ov_bb_Rp=Wmax_vec_ov_bb_Rp, Wmax_fit_ov_bb_Rp=Wmax_fit_ov_bb_Rp, Wmax_vec_rb_bb_Rp=Wmax_vec_rb_bb_Rp, Wmax_fit_rb_bb_Rp=Wmax_fit_rb_bb_Rp, WKE_vec_bb_Rp=WKE_vec_bb_Rp, WKE_fit_bb_Rp=WKE_fit_bb_Rp, WKE_vec_ov_bb_Rp=WKE_vec_ov_bb_Rp, WKE_fit_ov_bb_Rp=WKE_fit_ov_bb_Rp, WKE_vec_rb_bb_Rp=WKE_vec_rb_bb_Rp, WKE_fit_rb_bb_Rp=WKE_fit_rb_bb_Rp, Wmoist_vec_bb_Rp=moisture_vec_bb_Rp, Wmoist_fit_bb_Rp=moist_fit_bb_Rp, Wmoist_vec_ov_bb_Rp=moisture_vec_ov_bb_Rp, Wmoist_fit_ov_bb_Rp=moist_fit_ov_bb_Rp, Wmoist_vec_rb_bb_Rp=moisture_vec_rb_bb_Rp, Wmoist_fit_rb_bb_Rp=moist_fit_rb_bb_Rp)
np.savez("S_Mat_Fig_1b.npz", eta_c_vec_bb_Rp=eta_c_vec_bb_Rp, eta_c_fit_bb_Rp=eta_c_fit_bb_Rp, eta_c_vec_ov_bb_Rp=eta_c_vec_ov_bb_Rp, eta_c_fit_ov_bb_Rp=eta_c_fit_ov_bb_Rp, eta_c_vec_rb_bb_Rp=eta_c_vec_rb_bb_Rp, eta_c_fit_rb_bb_Rp=eta_c_fit_rb_bb_Rp, eta_mech_vec_bb_Rp=eta_mech_vec_bb_Rp, eta_mech_fit_bb_Rp=eta_mech_fit_bb_Rp, eta_mech_vec_ov_bb_Rp=eta_mech_vec_ov_bb_Rp, eta_mech_fit_ov_bb_Rp=eta_mech_fit_ov_bb_Rp, eta_mech_vec_rb_bb_Rp=eta_mech_vec_rb_bb_Rp, eta_mech_fit_rb_bb_Rp=eta_mech_fit_rb_bb_Rp, Qin_vec_bb_Rp=Qin_vec_bb_Rp, Qin_fit_bb_Rp=Qin_fit_bb_Rp, Qin_vec_ov_bb_Rp=Qin_vec_ov_bb_Rp, Qin_fit_ov_bb_Rp=Qin_fit_ov_bb_Rp, Qin_vec_rb_bb_Rp=Qin_vec_rb_bb_Rp, Qin_fit_rb_bb_Rp=Qin_fit_rb_bb_Rp)
np.savez("S_Mat_Fig_2.npz", Wp_vec_ov_bb_Rp=Wp_vec_ov_bb_Rp, Wp_vec_bb_Rp=Wp_vec_bb_Rp, Wp_vec_rb_bb_Rp=Wp_vec_rb_bb_Rp, Wp_fit_ov_bb_Rp=Wp_fit_ov_bb_Rp, Wp_fit_bb_Rp=Wp_fit_bb_Rp, Wp_fit_rb_bb_Rp=Wp_fit_rb_bb_Rp, dg_vec_ov_bb_Rp=dg_vec_ov_bb_Rp, dg_vec_bb_Rp=dg_vec_bb_Rp, dg_vec_rb_bb_Rp=dg_vec_rb_bb_Rp, dg_fit_ov_bb_Rp=dg_fit_ov_bb_Rp, dg_fit_bb_Rp=dg_fit_bb_Rp, dg_fit_rb_bb_Rp=dg_fit_rb_bb_Rp)
np.savez("S_Mat_Fig_3.npz", pr_fit_bb_Rp=pr_fit_bb_Rp, pr_vec_bb_Rp=pr_vec_bb_Rp, KE_vec_bb_Rp=KE_vec_bb_Rp, KE_fit_bb_Rp=KE_fit_bb_Rp, IKE_vec_bb_Rp=IKE_vec_bb_Rp, IKE_fit_bb_Rp=IKE_fit_bb_Rp, LHF_vec_bb_Rp=LHF_vec_bb_Rp, LHF_fit_bb_Rp=LHF_fit_bb_Rp, SHF_vec_bb_Rp=SHF_vec_bb_Rp, SHF_fit_bb_Rp=SHF_fit_bb_Rp, THF_vec_bb_Rp=THF_vec_bb_Rp, THF_fit_bb_Rp=THF_fit_bb_Rp, eta_mc_fit_bb_Rp=eta_mc_fit_bb_Rp, eta_mc_vec_bb_Rp=eta_mc_vec_bb_Rp, eta_mc_fit_ov_bb_Rp=eta_mc_fit_ov_bb_Rp, eta_mc_vec_ov_bb_Rp=eta_mc_vec_ov_bb_Rp, eta_mc_fit_rb_bb_Rp=eta_mc_fit_rb_bb_Rp, eta_mc_vec_rb_bb_Rp=eta_mc_vec_rb_bb_Rp, Tin_fit_bb_Rp=Tin_fit_bb_Rp, Tin_vec_bb_Rp=Tin_vec_bb_Rp, Tout_fit_bb_Rp=Tout_fit_bb_Rp, Tout_vec_bb_Rp=Tout_vec_bb_Rp, Tin_m_Tout_fit_bb_Rp=Tin_m_Tout_fit_bb_Rp, Tin_m_Tout_vec_bb_Rp=Tin_m_Tout_vec_bb_Rp)


#As stated in the main text, trends in all variables as SST increases are calculated as percentages of either the value of each variable at an SST of 299.5K for the 
#single-eyewall period results (and for all results with one value corresponding to each SST), or the mean value of each variable at an SST of 299.5K for the realistic period
#results. Here, we obtain the indices corresponding both to the entry 299.5K in the vector SSTs (used for trends in results derived from all MAFALDA trajectories and for 
#rainband circulation results) and the entry in the vector SST_vec_ov_bb_Rp corresponding to or closest to 299.5K:
SST_threshold_ind=np.where(np.asarray(SSTs)==299.5)[0][0] #Index of the entry "299.5" in SSTs
if len(np.where(np.asarray(SST_vec_ov_bb_Rp)==299.5)[0])==0: #If no eyewall circulation was identified for the 299.5K simulation, such that no entry in SST_vec_ov_bb_Rp is 
                                                             #equal to 299.5
    print("ERROR!!!- no eyewall circulation for reference simulation single-eyewall period") #If this error occurs, the user will need to manually define SST_threshold_ind_ov
                                                                                           #as the index corresponding to the SST simulation with an identified eyewall 
                                                                                           #circulation during its single-eyewall period (i.e. where the SST value is in 
                                                                                           #SST_vec_ov_bb_Rp) that is closest to 299.5K- such as 299K or 300K (see below).
    #SST_threshold_ind_ov=np.where(np.asarray(SST_vec_ov_bb_Rp)==299)[0][0] #Index of the entry "299" in eyewall SSTs
    #SST_threshold_ind_ov=np.where(np.asarray(SST_vec_ov_bb_Rp)==300)[0][0] #Index of the entry "300" in eyewall SSTs
else:
    SST_threshold_ind_ov=np.where(np.asarray(SST_vec_ov_bb_Rp)==299.5)[0][0] #Index of the entry "299.5" in eyewall SSTs
#print("Testing 299.5K indices:")
#print(SSTs[SST_threshold_ind]) #Should print 299.5
#print(SST_vec_ov_bb_Rp[SST_threshold_ind_ov]) #Should print 299.5 unless the error above was printed.

#Print trends (absolute values and as percentages) and associated p-values for all variables that we discuss in the main text
#Wmax trends and p-values
#Realistic periods results
#Whole circulation 
print("Wmax trend is "+ np.str((Wmax_fit[-1]-Wmax_fit[0])/(SSTs[-1]-SSTs[0]))) #Absolute value of trend
print("Wmax trend (%) is "+ np.str(100*(Wmax_fit[-1]-Wmax_fit[0])/(Wmax_vec[SST_threshold_ind]*(SSTs[-1]-SSTs[0])))) #Trend in %/K
print("p-value is "+np.str(p_value_Wm)) #Associated p-value
#Eyewall circulation
print("Wmax eyewall circulation trend is "+ np.str((Wmax_fit_ov[-1]-Wmax_fit_ov[0])/(SSTs[-1]-SSTs[0])))
print("Wmax eyewall circulation trend (%) is "+ np.str(100*(Wmax_fit_ov[-1]-Wmax_fit_ov[0])/(Wmax_vec_ov[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_Wm_ov))
#Rainband circulation
print("Wmax rainband circulation trend is "+ np.str((Wmax_fit_rb[-1]-Wmax_fit_rb[0])/(SSTs[-1]-SSTs[0])))
print("Wmax rainband circulation trend (%) is "+ np.str(100*(Wmax_fit_rb[-1]-Wmax_fit_rb[0])/(Wmax_vec_rb[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_Wm_rb))
#Single-eyewall periods results
#Whole circulation
print("Wmax trend for single-eyewall periods is "+ np.str((Wmax_fit_bb_Rp[-1]-Wmax_fit_bb_Rp[0])/(SSTs[-1]-SSTs[0])))
print("Wmax trend (%) for single-eyewall periods is "+ np.str(100*(Wmax_fit_bb_Rp[-1]-Wmax_fit_bb_Rp[0])/(Wmax_vec_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_Wmax_bb_Rp))
#Eyewall circulation
print("Wmax eyewall circulation trend for single-eyewall periods is "+ np.str((Wmax_fit_ov_bb_Rp[-1]-Wmax_fit_ov_bb_Rp[0])/(SST_vec_ov_bb_Rp[-1]-SST_vec_ov_bb_Rp[0])))
print("Wmax eyewall circulation trend (%) for single-eyewall periods is "+ np.str(100*(Wmax_fit_ov_bb_Rp[-1]-Wmax_fit_ov_bb_Rp[0])/(Wmax_vec_ov_bb_Rp[SST_threshold_ind_ov]*(SST_vec_ov_bb_Rp[-1]-SST_vec_ov_bb_Rp[0]))))
print("p-value is "+np.str(p_value_Wm_ov_bb_Rp))
#Rainband circulation
print("Wmax rainband circulation trend for single-eyewall periods is "+ np.str((Wmax_fit_rb_bb_Rp[-1]-Wmax_fit_rb_bb_Rp[0])/(SSTs[-1]-SSTs[0])))
print("Wmax rainband circulation trend (%) for single-eyewall periods is "+ np.str(100*(Wmax_fit_rb_bb_Rp[-1]-Wmax_fit_rb_bb_Rp[0])/(Wmax_vec_rb_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_Wm_rb_bb_Rp))

#WKE trends and p-values
print("WKE trend is "+ np.str((WKE_fit[-1]-WKE_fit[0])/(SSTs[-1]-SSTs[0])))
print("WKE trend (%) is "+ np.str(100*(WKE_fit[-1]-WKE_fit[0])/(WKE_vec[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_WKE))
print("WKE trend (W/m2) is "+ np.str((WKE_fit_2[-1]-WKE_fit_2[0])/(SSTs[-1]-SSTs[0])))
print("WKE trend (%, W/m2) is "+ np.str(100*(WKE_fit_2[-1]-WKE_fit_2[0])/(WKE_vec_2[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_WKE_2))
print("WKE eyewall circulation trend is "+ np.str((WKE_fit_ov[-1]-WKE_fit_ov[0])/(SSTs[-1]-SSTs[0])))
print("WKE eyewall circulation trend (%) is "+ np.str(100*(WKE_fit_ov[-1]-WKE_fit_ov[0])/(WKE_vec_ov[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_WKE_ov))
print("WKE rainband circulation trend is "+ np.str((WKE_fit_rb[-1]-WKE_fit_rb[0])/(SSTs[-1]-SSTs[0])))
print("WKE rainband circulation trend (%) is "+ np.str(100*(WKE_fit_rb[-1]-WKE_fit_rb[0])/(WKE_vec_rb[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_WKE_rb))
print("WKE trend for single-eyewall periods is "+ np.str((WKE_fit_bb_Rp[-1]-WKE_fit_bb_Rp[0])/(SSTs[-1]-SSTs[0])))
print("WKE trend (%) for single-eyewall periods is "+ np.str(100*(WKE_fit_bb_Rp[-1]-WKE_fit_bb_Rp[0])/(WKE_vec_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_WKE_bb_Rp))
print("WKE trend (W/m2) for single-eyewall periods is "+ np.str((WKE_fit_bb_Rp_2[-1]-WKE_fit_bb_Rp_2[0])/(SSTs[-1]-SSTs[0])))
print("WKE trend (%, W/m2) for single-eyewall periods is "+ np.str(100*(WKE_fit_bb_Rp_2[-1]-WKE_fit_bb_Rp_2[0])/(WKE_vec_bb_Rp_2[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_WKE_bb_Rp_2))
print("WKE eyewall circulation trend for single-eyewall periods is "+ np.str((WKE_fit_ov_bb_Rp[-1]-WKE_fit_ov_bb_Rp[0])/(SST_vec_ov_bb_Rp[-1]-SST_vec_ov_bb_Rp[0])))
print("WKE eyewall circulation trend (%) for single-eyewall periods is "+ np.str(100*(WKE_fit_ov_bb_Rp[-1]-WKE_fit_ov_bb_Rp[0])/(WKE_vec_ov_bb_Rp[SST_threshold_ind_ov]*(SST_vec_ov_bb_Rp[-1]-SST_vec_ov_bb_Rp[0]))))
print("p-value is "+np.str(p_value_WKE_ov_bb_Rp))
print("WKE rainband circulation trend for single-eyewall periods is "+ np.str((WKE_fit_rb_bb_Rp[-1]-WKE_fit_rb_bb_Rp[0])/(SSTs[-1]-SSTs[0])))
print("WKE rainband circulation trend (%) for single-eyewall periods is "+ np.str(100*(WKE_fit_rb_bb_Rp[-1]-WKE_fit_rb_bb_Rp[0])/(WKE_vec_rb_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_WKE_rb_bb_Rp))

#Wmoist trends and p-values
print("Wmoist trend is "+ np.str((moisture_fit[-1]-moisture_fit[0])/(SSTs[-1]-SSTs[0])))
print("Wmoist trend (%) is "+ np.str(100*(moisture_fit[-1]-moisture_fit[0])/(moisture_vec[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_moisture))
print("Wmoist eyewall circulation trend is "+ np.str((moist_fit_ov[-1]-moist_fit_ov[0])/(SSTs[-1]-SSTs[0])))
print("Wmoist eyewall circulation trend (%) is "+ np.str(100*(moist_fit_ov[-1]-moist_fit_ov[0])/(moisture_vec_ov[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_Wmo_ov))
print("Wmoist rainband circulation trend is "+ np.str((moist_fit_rb[-1]-moist_fit_rb[0])/(SSTs[-1]-SSTs[0])))
print("Wmoist rainband circulation trend (%) is "+ np.str(100*(moist_fit_rb[-1]-moist_fit_rb[0])/(moisture_vec_rb[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_Wmo_rb))
print("Wmoist trend for single-eyewall periods is "+ np.str((moist_fit_bb_Rp[-1]-moist_fit_bb_Rp[0])/(SSTs[-1]-SSTs[0])))
print("Wmoist trend (%) for single-eyewall periods is "+ np.str(100*(moist_fit_bb_Rp[-1]-moist_fit_bb_Rp[0])/(moisture_vec_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_moist_bb_Rp))
print("Wmoist eyewall circulation trend for single-eyewall periods is "+ np.str((moist_fit_ov_bb_Rp[-1]-moist_fit_ov_bb_Rp[0])/(SST_vec_ov_bb_Rp[-1]-SST_vec_ov_bb_Rp[0])))
print("Wmoist eyewall circulation trend (%) for single-eyewall periods is "+ np.str(100*(moist_fit_ov_bb_Rp[-1]-moist_fit_ov_bb_Rp[0])/(moisture_vec_ov_bb_Rp[SST_threshold_ind_ov]*(SST_vec_ov_bb_Rp[-1]-SST_vec_ov_bb_Rp[0]))))
print("p-value is "+np.str(p_value_Wmo_ov_bb_Rp))
print("Wmoist rainband circulation trend for single-eyewall periods is "+ np.str((moist_fit_rb_bb_Rp[-1]-moist_fit_rb_bb_Rp[0])/(SSTs[-1]-SSTs[0])))
print("Wmoist rainband circulation trend (%) for single-eyewall periods is "+ np.str(100*(moist_fit_rb_bb_Rp[-1]-moist_fit_rb_bb_Rp[0])/(moisture_vec_rb_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_Wmo_rb_bb_Rp))

#Wp trends and p-values
print("Wp trend is "+ np.str((Wp_fit[-1]-Wp_fit[0])/(SSTs[-1]-SSTs[0])))
print("Wp trend (%) is "+ np.str(100*(Wp_fit[-1]-Wp_fit[0])/(Wp_vec[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_Wp))
print("Wp trend (W/m2) is "+ np.str((Wp_fit_2[-1]-Wp_fit_2[0])/(SSTs[-1]-SSTs[0])))
print("Wp trend (%, W/m2) is "+ np.str(100*(Wp_fit_2[-1]-Wp_fit_2[0])/(Wp_vec_2[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_Wp_2))
print("Wp eyewall circulation trend is "+ np.str((Wp_fit_ov[-1]-Wp_fit_ov[0])/(SSTs[-1]-SSTs[0])))
print("Wp eyewall circulation trend (%) is "+ np.str(100*(Wp_fit_ov[-1]-Wp_fit_ov[0])/(Wp_vec_ov[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_Wp_ov))
print("Wp rainband circulation trend is "+ np.str((Wp_fit_rb[-1]-Wp_fit_rb[0])/(SSTs[-1]-SSTs[0])))
print("Wp rainband circulation trend (%) is "+ np.str(100*(Wp_fit_rb[-1]-Wp_fit_rb[0])/(Wp_vec_rb[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_Wp))
print("Wp trend for single-eyewall periods is "+ np.str((Wp_fit_bb_Rp[-1]-Wp_fit_bb_Rp[0])/((SSTs[-1]-SSTs[0]))))
print("Wp trend (%) for single-eyewall periods is "+ np.str(100*(Wp_fit_bb_Rp[-1]-Wp_fit_bb_Rp[0])/(Wp_vec_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_Wp_bb_Rp))
print("Wp trend (W/m2) for single-eyewall periods is "+ np.str((Wp_fit_bb_Rp_2[-1]-Wp_fit_bb_Rp_2[0])/((SSTs[-1]-SSTs[0]))))
print("Wp trend (%, W/m2) for single-eyewall periods is "+ np.str(100*(Wp_fit_bb_Rp_2[-1]-Wp_fit_bb_Rp_2[0])/(Wp_vec_bb_Rp_2[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_Wp_bb_Rp_2))
print("Wp eyewall circulation trend for single-eyewall periods is "+ np.str((Wp_fit_ov_bb_Rp[-1]-Wp_fit_ov_bb_Rp[0])/(SST_vec_ov_bb_Rp[-1]-SST_vec_ov_bb_Rp[0])))
print("Wp eyewall circulation trend (%) for single-eyewall periods is "+ np.str(100*(Wp_fit_ov_bb_Rp[-1]-Wp_fit_ov_bb_Rp[0])/(Wp_vec_ov_bb_Rp[SST_threshold_ind_ov]*(SST_vec_ov_bb_Rp[-1]-SST_vec_ov_bb_Rp[0]))))
print("p-value is "+np.str(p_value_Wp_ov_bb_Rp))
print("Wp rainband circulation trend for single-eyewall periods is "+ np.str((Wp_fit_rb_bb_Rp[-1]-Wp_fit_rb_bb_Rp[0])/(SST_vec_rb_bb_Rp[-1]-SST_vec_rb_bb_Rp[0])))
print("Wp rainband circulation trend (%) for single-eyewall periods is "+ np.str(100*(Wp_fit_rb_bb_Rp[-1]-Wp_fit_rb_bb_Rp[0])/(Wp_vec_rb_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_Wp_rb_bb_Rp))

#dG trends and p-values
print("dG trend is "+ np.str((dg_fit[-1]-dg_fit[0])/(SSTs[-1]-SSTs[0]))) 
print("dG trend (%) is "+ np.str(100*(dg_fit[-1]-dg_fit[0])/(dg_vec[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_dg))
print("dG trend (W/m2) is "+ np.str((dg_fit_2[-1]-dg_fit_2[0])/(SSTs[-1]-SSTs[0])))
print("dG trend (%, W/m2) is "+ np.str(100*(dg_fit_2[-1]-dg_fit_2[0])/(dg_vec_2[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_dg_2))
print("dG eyewall circulation trend is "+ np.str((dg_fit_ov[-1]-dg_fit_ov[0])/(SSTs[-1]-SSTs[0])))
print("dG eyewall circulation trend (%) is "+ np.str(100*(dg_fit_ov[-1]-dg_fit_ov[0])/(dg_vec_ov[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_dg_ov))
print("dG rainband circulation trend is "+ np.str((dg_fit_rb[-1]-dg_fit_rb[0])/(SSTs[-1]-SSTs[0])))
print("dG rainband circulation trend (%) is "+ np.str(100*(dg_fit_rb[-1]-dg_fit_rb[0])/(dg_vec_rb[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_dg_rb))
print("dG trend for single-eyewall periods is "+ np.str((dg_fit_bb_Rp[-1]-dg_fit_bb_Rp[0])/((SSTs[-1]-SSTs[0]))))
print("dG trend (%) for single-eyewall periods is "+ np.str(100*(dg_fit_bb_Rp[-1]-dg_fit_bb_Rp[0])/(dg_vec_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_dg_bb_Rp))
print("dG trend (%, W/m2) for single-eyewall periods is "+ np.str(100*(dg_fit_bb_Rp_2[-1]-dg_fit_bb_Rp_2[0])/(dg_vec_bb_Rp_2[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_dg_bb_Rp_2))
print("dG eyewall circulation trend for single-eyewall periods is "+ np.str((dg_fit_ov_bb_Rp[-1]-dg_fit_ov_bb_Rp[0])/((SST_vec_ov_bb_Rp[-1]-SST_vec_ov_bb_Rp[0]))))
print("dG eyewall circulation trend (%) for single-eyewall periods is "+ np.str(100*(dg_fit_ov_bb_Rp[-1]-dg_fit_ov_bb_Rp[0])/(dg_vec_ov_bb_Rp[SST_threshold_ind_ov]*(SST_vec_ov_bb_Rp[-1]-SST_vec_ov_bb_Rp[0]))))
print("p-value is "+np.str(p_value_dg_ov_bb_Rp))
print("dG rainband circulation trend for single-eyewall periods is "+ np.str(100*(dg_fit_rb_bb_Rp[-1]-dg_fit_rb_bb_Rp[0])/((SSTs[-1]-SSTs[0]))))
print("dG rainband circulation trend (%) for single-eyewall periods is "+ np.str(100*(dg_fit_rb_bb_Rp[-1]-dg_fit_rb_bb_Rp[0])/(dg_vec_rb_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_dg_rb_bb_Rp))

#Qin trends and p-values
print("Qin trend is "+ np.str((Qin_fit[-1]-Qin_fit[0])/(SSTs[-1]-SSTs[0])))
print("Qin trend (%) is "+ np.str(100*(Qin_fit[-1]-Qin_fit[0])/(Qin_vec[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_Qin))
print("Qin trend (W/m2) is "+ np.str((Qin_fit_2[-1]-Qin_fit_2[0])/(SSTs[-1]-SSTs[0])))
print("Qin trend (%, W/m2) is "+ np.str(100*(Qin_fit_2[-1]-Qin_fit_2[0])/(Qin_vec_2[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_Qin_2))
print("Qin eyewall circulation trend is "+ np.str((Qin_fit_ov[-1]-Qin_fit_ov[0])/(SSTs[-1]-SSTs[0])))
print("Qin eyewall circulation trend (%) is "+ np.str(100*(Qin_fit_ov[-1]-Qin_fit_ov[0])/(Qin_vec_ov[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_Qin_ov))
print("Qin rainband circulation trend is "+ np.str((Qin_fit_rb[-1]-Qin_fit_rb[0])/(SSTs[-1]-SSTs[0])))
print("Qin rainband circulation trend (%) is "+ np.str(100*(Qin_fit_rb[-1]-Qin_fit_rb[0])/(Qin_vec_rb[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_Qin_rb))
print("Qin trend for single-eyewall periods is "+ np.str((Qin_fit_bb_Rp[-1]-Qin_fit_bb_Rp[0])/(SSTs[-1]-SSTs[0])))
print("Qin trend (%) for single-eyewall periods is "+ np.str(100*(Qin_fit_bb_Rp[-1]-Qin_fit_bb_Rp[0])/(Qin_vec_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_Qin_bb_Rp))
print("Qin trend (W/m2) for single-eyewall periods is "+ np.str((Qin_fit_bb_Rp_2[-1]-Qin_fit_bb_Rp_2[0])/(SSTs[-1]-SSTs[0])))
print("Qin trend (%, W/m2) for single-eyewall periods is "+ np.str(100*(Qin_fit_bb_Rp_2[-1]-Qin_fit_bb_Rp_2[0])/(Qin_vec_bb_Rp_2[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_Qin_bb_Rp_2))
print("Qin eyewall circulation trend for single-eyewall periods is "+ np.str((Qin_fit_ov_bb_Rp[-1]-Qin_fit_ov_bb_Rp[0])/(SST_vec_ov_bb_Rp[-1]-SST_vec_ov_bb_Rp[0])))
print("Qin eyewall circulation trend (%) for single-eyewall periods is "+ np.str(100*(Qin_fit_ov_bb_Rp[-1]-Qin_fit_ov_bb_Rp[0])/(Qin_vec_ov_bb_Rp[SST_threshold_ind_ov]*(SST_vec_ov_bb_Rp[-1]-SST_vec_ov_bb_Rp[0]))))
print("p-value is "+np.str(p_value_Qin_ov_bb_Rp))
print("Qin rainband circulation trend for single-eyewall periods is "+ np.str((Qin_fit_rb_bb_Rp[-1]-Qin_fit_rb_bb_Rp[0])/(SSTs[-1]-SSTs[0])))
print("Qin rainband circulation trend (%) for single-eyewall periods is "+ np.str(100*(Qin_fit_rb_bb_Rp[-1]-Qin_fit_rb_bb_Rp[0])/(Qin_vec_rb_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_Qin_rb_bb_Rp))

#Mechanical efficiency trends and p-values
print("eta_mech trend is "+ np.str((eta_mech_fit[-1]-eta_mech_fit[0])/(SSTs[-1]-SSTs[0])))
print("eta_mech trend (%) is "+ np.str(100*(eta_mech_fit[-1]-eta_mech_fit[0])/(eta_mech_vec[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_eme))
print("eta_mech eyewall circulation trend is "+ np.str((eta_mech_fit_ov[-1]-eta_mech_fit_ov[0])/(SSTs[-1]-SSTs[0])))
print("eta_mech eyewall circulation trend (%) is "+ np.str(100*(eta_mech_fit_ov[-1]-eta_mech_fit_ov[0])/(eta_mech_vec_ov[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_eme_ov))
print("eta_mech rainband circulation trend is "+ np.str((eta_mech_fit_rb[-1]-eta_mech_fit_rb[0])/(SSTs[-1]-SSTs[0])))
print("eta_mech rainband circulation trend (%) is "+ np.str(100*(eta_mech_fit_rb[-1]-eta_mech_fit_rb[0])/(eta_mech_vec_rb[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_eme_rb))
print("eta_mech trend for single-eyewall periods is "+ np.str((eta_mech_fit_bb_Rp[-1]-eta_mech_fit_bb_Rp[0])/(SSTs[-1]-SSTs[0])))
print("eta_mech trend (%) for single-eyewall periods is "+ np.str(100*(eta_mech_fit_bb_Rp[-1]-eta_mech_fit_bb_Rp[0])/(eta_mech_vec_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_eme_bb_Rp))
print("eta_mech eyewall circulation trend for single-eyewall periods is "+ np.str((eta_mech_fit_ov_bb_Rp[-1]-eta_mech_fit_ov_bb_Rp[0])/(SST_vec_ov_bb_Rp[-1]-SST_vec_ov_bb_Rp[0])))
print("eta_mech eyewall circulation trend (%) for single-eyewall periods is "+ np.str(100*(eta_mech_fit_ov_bb_Rp[-1]-eta_mech_fit_ov_bb_Rp[0])/(eta_mech_vec_ov_bb_Rp[SST_threshold_ind_ov]*(SST_vec_ov_bb_Rp[-1]-SST_vec_ov_bb_Rp[0]))))
print("p-value is "+np.str(p_value_eme_ov_bb_Rp))
print("eta_mech rainband circulation trend for single-eyewall periods is "+ np.str((eta_mech_fit_rb_bb_Rp[-1]-eta_mech_fit_rb_bb_Rp[0])/(SSTs[-1]-SSTs[0])))
print("eta_mech rainband circulation trend (%) for single-eyewall periods is "+ np.str(100*(eta_mech_fit_rb_bb_Rp[-1]-eta_mech_fit_rb_bb_Rp[0])/(eta_mech_vec_rb_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_eme_rb_bb_Rp))

#Carnot efficiency trends and p-values
print("eta_c trend is "+ np.str((eta_c_fit[-1]-eta_c_fit[0])/((SSTs[-1]-SSTs[0]))))
print("eta_c trend (%) is "+ np.str(100*(eta_c_fit[-1]-eta_c_fit[0])/(eta_c_vec[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_ec))
print("eta_c eyewall circulation trend is "+ np.str((eta_c_fit_ov[-1]-eta_c_fit_ov[0])/((SSTs[-1]-SSTs[0]))))
print("eta_c eyewall circulation trend (%) is "+ np.str(100*(eta_c_fit_ov[-1]-eta_c_fit_ov[0])/(eta_c_vec_ov[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_ec_ov))
print("eta_c rainband circulation trend is "+ np.str((eta_c_fit_rb[-1]-eta_c_fit_rb[0])/((SSTs[-1]-SSTs[0]))))
print("eta_c rainband circulation trend (%) is "+ np.str(100*(eta_c_fit_rb[-1]-eta_c_fit_rb[0])/(eta_c_vec_rb[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_ec_rb))
print("eta_c trend for single-eyewall periods is "+ np.str((eta_c_fit_bb_Rp[-1]-eta_c_fit_bb_Rp[0])/(SSTs[-1]-SSTs[0])))
print("eta_c trend (%) for single-eyewall periods is "+ np.str(100*(eta_c_fit_bb_Rp[-1]-eta_c_fit_bb_Rp[0])/(eta_c_vec_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_ec_bb_Rp))
print("eta_c eyewall circulation trend for single-eyewall periods is "+ np.str((eta_c_fit_ov_bb_Rp[-1]-eta_c_fit_ov_bb_Rp[0])/(SST_vec_ov_bb_Rp[-1]-SST_vec_ov_bb_Rp[0])))
print("eta_c eyewall circulation trend (%) for single-eyewall periods is "+ np.str(100*(eta_c_fit_ov_bb_Rp[-1]-eta_c_fit_ov_bb_Rp[0])/(eta_c_vec_ov_bb_Rp[SST_threshold_ind_ov]*(SST_vec_ov_bb_Rp[-1]-SST_vec_ov_bb_Rp[0]))))
print("p-value is "+np.str(p_value_ec_ov_bb_Rp))
print("eta_c rainband circulation trend for single-eyewall periods is "+ np.str((eta_c_fit_rb_bb_Rp[-1]-eta_c_fit_rb_bb_Rp[0])/(SSTs[-1]-SSTs[0])))
print("eta_c rainband circulation trend (%) for single-eyewall periods is "+ np.str(100*(eta_c_fit_rb_bb_Rp[-1]-eta_c_fit_rb_bb_Rp[0])/(eta_c_vec_rb_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_ec_rb_bb_Rp))

#Relative efficiency trends and p-values
print("eta_mech/eta_c trend is "+ np.str((eta_mc_fit[-1]-eta_mc_fit[0])/((SSTs[-1]-SSTs[0]))))
print("eta_mech/eta_c trend (%) is "+ np.str(100*(eta_mc_fit[-1]-eta_mc_fit[0])/(eta_mc_vec[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_emc))
print("eta_mech/eta_c eyewall circulation trend is "+ np.str((eta_mc_fit_ov[-1]-eta_mc_fit_ov[0])/((SSTs[-1]-SSTs[0]))))
print("eta_mech/eta_c eyewall circulation trend (%) is "+ np.str(100*(eta_mc_fit_ov[-1]-eta_mc_fit_ov[0])/(eta_mc_vec_ov[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_emc_ov))
print("eta_mech/eta_c rainband circulation trend is "+ np.str((eta_mc_fit_rb[-1]-eta_mc_fit_rb[0])/((SSTs[-1]-SSTs[0]))))
print("eta_mech/eta_c rainband circulation trend (%) is "+ np.str(100*(eta_mc_fit_rb[-1]-eta_mc_fit_rb[0])/(eta_mc_vec_rb[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_emc_rb))
print("eta_mech/eta_c trend for single-eyewall periods is "+ np.str((eta_mc_fit_bb_Rp[-1]-eta_mc_fit_bb_Rp[0])/(SSTs[-1]-SSTs[0])))
print("eta_mech/eta_c trend (%) for single-eyewall periods is "+ np.str(100*(eta_mc_fit_bb_Rp[-1]-eta_mc_fit_bb_Rp[0])/(eta_mc_vec_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_emc_bb_Rp))
print("eta_mech/eta_c eyewall circulation trend for single-eyewall periods is "+ np.str((eta_mc_fit_ov_bb_Rp[-1]-eta_mc_fit_ov_bb_Rp[0])/(SST_vec_ov_bb_Rp[-1]-SST_vec_ov_bb_Rp[0])))
print("eta_mech/eta_c eyewall circulation trend (%) for single-eyewall periods is "+ np.str(100*(eta_mc_fit_ov_bb_Rp[-1]-eta_mc_fit_ov_bb_Rp[0])/(eta_mc_vec_ov_bb_Rp[SST_threshold_ind_ov]*(SST_vec_ov_bb_Rp[-1]-SST_vec_ov_bb_Rp[0]))))
print("p-value is "+np.str(p_value_emc_ov_bb_Rp))
print("eta_mech/eta_c rainband circulation trend for single-eyewall periods is "+ np.str((eta_mc_fit_rb_bb_Rp[-1]-eta_mc_fit_rb_bb_Rp[0])/(SSTs[-1]-SSTs[0])))
print("eta_mech/eta_c rainband circulation trend (%) for single-eyewall periods is "+ np.str(100*(eta_mc_fit_rb_bb_Rp[-1]-eta_mc_fit_rb_bb_Rp[0])/(eta_mc_vec_rb_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_emc_rb_bb_Rp))

#Tin trends and p-values
print("Tin trend (%) is "+ np.str((Tin_fit[-1]-Tin_fit[0])/((SSTs[-1]-SSTs[0]))))
print("Tin trend is "+ np.str(100*(Tin_fit[-1]-Tin_fit[0])/(Tin_vec[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_ti))
print("Tin eyewall circulation trend (%) is "+ np.str((Tin_fit_ov[-1]-Tin_fit_ov[0])/((SSTs[-1]-SSTs[0]))))
print("Tin eyewall circulation trend is "+ np.str(100*(Tin_fit_ov[-1]-Tin_fit_ov[0])/(Tin_vec_ov[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_ti_ov))
print("Tin rainband circulation trend is "+ np.str((Tin_fit_rb[-1]-Tin_fit_rb[0])/((SSTs[-1]-SSTs[0]))))
print("Tin rainband circulation trend (%) is "+ np.str(100*(Tin_fit_rb[-1]-Tin_fit_rb[0])/(Tin_vec_rb[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_ti_rb))
print("Tin trend for single-eyewall periods is "+ np.str((Tin_fit_bb_Rp[-1]-Tin_fit_bb_Rp[0])/(SSTs[-1]-SSTs[0])))
print("Tin trend (%) for single-eyewall periods is "+ np.str(100*(Tin_fit_bb_Rp[-1]-Tin_fit_bb_Rp[0])/(Tin_vec_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_ti_bb_Rp))
print("Tin eyewall circulation trend for single-eyewall periods is "+ np.str((Tin_fit_ov_bb_Rp[-1]-Tin_fit_ov_bb_Rp[0])/(SST_vec_ov_bb_Rp[-1]-SST_vec_ov_bb_Rp[0])))
print("Tin eyewall circulation trend (%) for single-eyewall periods is "+ np.str(100*(Tin_fit_ov_bb_Rp[-1]-Tin_fit_ov_bb_Rp[0])/(Tin_vec_ov_bb_Rp[SST_threshold_ind_ov]*(SST_vec_ov_bb_Rp[-1]-SST_vec_ov_bb_Rp[0]))))
print("p-value is "+np.str(p_value_ti_ov_bb_Rp))
print("Tin rainband circulation trend for single-eyewall periods is "+ np.str((Tin_fit_rb_bb_Rp[-1]-Tin_fit_rb_bb_Rp[0])/(SSTs[-1]-SSTs[0])))
print("Tin rainband circulation trend (%) for single-eyewall periods is "+ np.str(100*(Tin_fit_rb_bb_Rp[-1]-Tin_fit_rb_bb_Rp[0])/(Tin_vec_rb_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_ti_rb_bb_Rp))

#Tout trends and p-values
print("Tout trend is "+ np.str((Tout_fit[-1]-Tout_fit[0])/((SSTs[-1]-SSTs[0]))))
print("Tout trend (%) is "+ np.str(100*(Tout_fit[-1]-Tout_fit[0])/(Tout_vec[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_to))
print("Tout eyewall circulation trend is "+ np.str((Tout_fit_ov[-1]-Tout_fit_ov[0])/((SSTs[-1]-SSTs[0]))))
print("Tout eyewall circulation trend (%) is "+ np.str(100*(Tout_fit_ov[-1]-Tout_fit_ov[0])/(Tout_vec_ov[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_to_ov))
print("Tout rainband circulation trend is "+ np.str((Tout_fit_rb[-1]-Tout_fit_rb[0])/((SSTs[-1]-SSTs[0]))))
print("Tout rainband circulation trend (%) is "+ np.str(100*(Tout_fit_rb[-1]-Tout_fit_rb[0])/(Tout_vec_rb[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_to_rb))
print("Tout trend for single-eyewall periods is "+ np.str((Tout_fit_bb_Rp[-1]-Tout_fit_bb_Rp[0])/(SSTs[-1]-SSTs[0])))
print("Tout trend (%) for single-eyewall periods is "+ np.str(100*(Tout_fit_bb_Rp[-1]-Tout_fit_bb_Rp[0])/(Tout_vec_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_to_bb_Rp))
print("Tout eyewall circulation trend for single-eyewall periods is "+ np.str((Tout_fit_ov_bb_Rp[-1]-Tout_fit_ov_bb_Rp[0])/(SST_vec_ov_bb_Rp[-1]-SST_vec_ov_bb_Rp[0])))
print("Tout eyewall circulation trend (%) for single-eyewall periods is "+ np.str(100*(Tout_fit_ov_bb_Rp[-1]-Tout_fit_ov_bb_Rp[0])/(Tout_vec_ov_bb_Rp[SST_threshold_ind_ov]*(SST_vec_ov_bb_Rp[-1]-SST_vec_ov_bb_Rp[0]))))
print("p-value is "+np.str(p_value_to_ov_bb_Rp))
print("Tout rainband circulation trend for single-eyewall periods is "+ np.str((Tout_fit_rb_bb_Rp[-1]-Tout_fit_rb_bb_Rp[0])/(SSTs[-1]-SSTs[0])))
print("Tout rainband circulation trend (%) for single-eyewall periods is "+ np.str(100*(Tout_fit_rb_bb_Rp[-1]-Tout_fit_rb_bb_Rp[0])/(Tout_vec_rb_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_to_rb_bb_Rp))

#Tin-Tout trends and p-values
print("Tin-Tout trend is "+ np.str((Tin_m_Tout_fit[-1]-Tin_m_Tout_fit[0])/((SSTs[-1]-SSTs[0]))))
print("Tin-Tout trend (%) is "+ np.str(100*(Tin_m_Tout_fit[-1]-Tin_m_Tout_fit[0])/(Tin_m_Tout_vec[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_timo))
print("Tin-Tout eyewall circulation trend is "+ np.str((Tin_m_Tout_fit_ov[-1]-Tin_m_Tout_fit_ov[0])/((SSTs[-1]-SSTs[0]))))
print("Tin-Tout eyewall circulation trend (%) is "+ np.str(100*(Tin_m_Tout_fit_ov[-1]-Tin_m_Tout_fit_ov[0])/(Tin_m_Tout_vec_ov[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_timo_ov))
print("Tin-Tout rainband circulation trend is "+ np.str((Tin_m_Tout_fit_rb[-1]-Tin_m_Tout_fit_rb[0])/((SSTs[-1]-SSTs[0]))))
print("Tin-Tout rainband circulation trend (%) is "+ np.str(100*(Tin_m_Tout_fit_rb[-1]-Tin_m_Tout_fit_rb[0])/(Tin_m_Tout_vec_rb[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_timo_rb))
print("Tin-Tout trend for single-eyewall periods is "+ np.str((Tin_m_Tout_fit_bb_Rp[-1]-Tin_m_Tout_fit_bb_Rp[0])/(SSTs[-1]-SSTs[0])))
print("Tin-Tout trend (%) for single-eyewall periods is "+ np.str(100*(Tin_m_Tout_fit_bb_Rp[-1]-Tin_m_Tout_fit_bb_Rp[0])/(Tin_m_Tout_vec_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_timo_bb_Rp))
print("Tin-Tout eyewall circulation trend for single-eyewall periods is "+ np.str((Tin_m_Tout_fit_ov_bb_Rp[-1]-Tin_m_Tout_fit_ov_bb_Rp[0])/(SST_vec_ov_bb_Rp[-1]-SST_vec_ov_bb_Rp[0])))
print("Tin-Tout eyewall circulation trend (%) for single-eyewall periods is "+ np.str(100*(Tin_m_Tout_fit_ov_bb_Rp[-1]-Tin_m_Tout_fit_ov_bb_Rp[0])/(Tin_m_Tout_vec_ov_bb_Rp[SST_threshold_ind_ov]*(SST_vec_ov_bb_Rp[-1]-SST_vec_ov_bb_Rp[0]))))
print("p-value is "+np.str(p_value_timo_ov_bb_Rp))
print("Tin-Tout rainband circulation trend for single-eyewall periods is "+ np.str((Tin_m_Tout_fit_rb_bb_Rp[-1]-Tin_m_Tout_fit_rb_bb_Rp[0])/(SSTs[-1]-SSTs[0])))
print("Tin-Tout rainband circulation trend (%) for single-eyewall periods is "+ np.str(100*(Tin_m_Tout_fit_rb_bb_Rp[-1]-Tin_m_Tout_fit_rb_bb_Rp[0])/(Tin_m_Tout_vec_rb_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p-value is "+np.str(p_value_timo_rb_bb_Rp))

print("Number of eyewall levels trend is "+ np.str((ol_fit[-1]-ol_fit[0])/((SSTs[-1]-SSTs[0]))))
print("Number of eyewall levels trend (%) is "+ np.str(100*(ol_fit[-1]-ol_fit[0])/((ol_vec[SST_threshold_ind])*(SSTs[-1]-SSTs[0]))))
print("p value is "+np.str(p_value_ol))

#vmax-associated KE trends and p-values
print("vmax KE trend is "+ np.str((KE_fit[-1]-KE_fit[0])/((SSTs[-1]-SSTs[0]))))
print("vmax KE trend (%) is "+ np.str(100*(KE_fit[-1]-KE_fit[0])/(KE_vec[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p value is "+np.str(p_value_ke))
print("vmax KE trend for single-eyewall periods is "+ np.str((KE_fit_bb_Rp[-1]-KE_fit_bb_Rp[0])/(SSTs[-1]-SSTs[0])))
print("vmax KE trend (%) for single-eyewall periods is "+ np.str(100*(KE_fit_bb_Rp[-1]-KE_fit_bb_Rp[0])/(KE_vec_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p value is "+np.str(p_value_ke_bb_Rp))

#vpi-associated KE trends and p-values
print("vpi KE trend is "+ np.str((KE_pi_fit[-1]-KE_pi_fit[0])/(SSTs[-1]-SSTs[0])))
print("vpi KE trend (%) is "+ np.str(100*(KE_pi_fit[-1]-KE_pi_fit[0])/(KE_pi_vec[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p value is "+np.str(p_value_kpi_bb_Rp))

#Integrated kinetic energy trends and p-values
print("IKE trend is "+ np.str((IKE_fit[-1]-IKE_fit[0])/((SSTs[-1]-SSTs[0]))))
print("IKE trend (%) is "+ np.str(100*(IKE_fit[-1]-IKE_fit[0])/(IKE_vec[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p value is "+np.str(p_value_ike))
print("IKE trend for single-eyewall periods is "+ np.str((IKE_fit_bb_Rp[-1]-IKE_fit_bb_Rp[0])/(SSTs[-1]-SSTs[0])))
print("IKE trend (%) for single-eyewall periods is "+ np.str(100*(IKE_fit_bb_Rp[-1]-IKE_fit_bb_Rp[0])/(IKE_vec_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p value is "+np.str(p_value_ike_bb_Rp))

#Surface precipitation rate trends and p-values
print("Surface precipitation rate trend is "+ np.str((pr_fit[-1]-pr_fit[0])/((SSTs[-1]-SSTs[0]))))
print("Surface precipitation rate trend (%) is "+ np.str(100*(pr_fit[-1]-pr_fit[0])/(pr_vec[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p value is "+np.str(p_value_pr))
print("Surface precipitation rate trend for single-eyewall periods is "+ np.str((pr_fit_bb_Rp[-1]-pr_fit_bb_Rp[0])/(SSTs[-1]-SSTs[0])))
print("Surface precipitation rate trend (%) for single-eyewall periods is "+ np.str(100*(pr_fit_bb_Rp[-1]-pr_fit_bb_Rp[0])/(pr_vec_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p value is "+np.str(p_value_pr_bb_Rp))

#Surface sensible heat flux trends and p-values
print("SHF trend is "+ np.str((SHF_fit[-1]-SHF_fit[0])/((SSTs[-1]-SSTs[0]))))
print("SHF trend (%) is "+ np.str(100*(SHF_fit[-1]-SHF_fit[0])/(SHF_vec[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p value is "+np.str(p_value_sh))
print("SHF trend for single-eyewall periods is "+ np.str((SHF_fit_bb_Rp[-1]-SHF_fit_bb_Rp[0])/(SSTs[-1]-SSTs[0])))
print("SHF trend (%) for single-eyewall periods is "+ np.str(100*(SHF_fit_bb_Rp[-1]-SHF_fit_bb_Rp[0])/(SHF_vec_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p value is "+np.str(p_value_sh_bb_Rp))

#Surface latent heat flux trends and p-values
print("LHF trend is "+ np.str((LHF_fit[-1]-LHF_fit[0])/((SSTs[-1]-SSTs[0]))))
print("LHF trend (%) is "+ np.str(100*(LHF_fit[-1]-LHF_fit[0])/(LHF_vec[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p value is "+np.str(p_value_lh))
print("LHF trend for single-eyewall periods is "+ np.str((LHF_fit_bb_Rp[-1]-LHF_fit_bb_Rp[0])/(SSTs[-1]-SSTs[0])))
print("LHF trend (%) for single-eyewall periods is "+ np.str(100*(LHF_fit_bb_Rp[-1]-LHF_fit_bb_Rp[0])/(LHF_vec_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p value is "+np.str(p_value_lh_bb_Rp))

#Total surface heat flux trends and p-values
print("THF trend is "+ np.str((THF_fit[-1]-THF_fit[0])/(SSTs[-1]-SSTs[0])))
print("THF trend (%) is "+ np.str(100*(THF_fit[-1]-THF_fit[0])/(THF_vec[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p value is "+np.str(p_value_th))
print("THF trend for single-eyewall periods is "+ np.str((THF_fit_bb_Rp[-1]-THF_fit_bb_Rp[0])/(SSTs[-1]-SSTs[0])))
print("THF trend (%) for single-eyewall periods is "+ np.str(100*(THF_fit_bb_Rp[-1]-THF_fit_bb_Rp[0])/(THF_vec_bb_Rp[SST_threshold_ind]*(SSTs[-1]-SSTs[0]))))
print("p value is "+np.str(p_value_th_bb_Rp))

